"""_____________________________________________________________________

:PROJECT: LARAsuite

*lara_django_data high_level_interface *

:details: lara_django_data high_level_interface.
         - generated with 'lara-django-dev generate_high_level_interface lara_django_data
:authors: mark doerr <mark.doerr@uni-greifswald.de>

.. note:: -
.. todo:: - 
________________________________________________________________________
"""

import json
import asyncio
import logging
import grpc
from typing import Union

from google.protobuf.struct_pb2 import Struct
from google.protobuf.json_format import MessageToDict

import lara_django_base_grpc.v1.lara_django_base_pb2 as lara_django_base_pb2
import lara_django_base_grpc.v1.lara_django_base_pb2_grpc as lara_django_base_pb2_grpc

import lara_django_data_grpc.v1.lara_django_data_pb2 as lara_django_data_pb2
import lara_django_data_grpc.v1.lara_django_data_pb2_grpc as lara_django_data_pb2_grpc

import  lara_django_base_grpc.lara_django_base_data_model as base_dm
import  lara_django_base_grpc.lara_django_base_interface as base_if
from  lara_django_base_grpc.abstract_interface import LARAInterface, GRPCChannelSingleton, create_file,  export_file, import_file, id_cache, update_image, update_file

import  lara_django_data_grpc.lara_django_data_data_model as data_dm 



#_________________  ExtraData  ______________________


class ExtraDataInterface:
    def __init__(self, channel: grpc.Channel = None, default_namespace_uri : str = None) -> None:
        self.default_namespace_uri = None
        self.default_namespace_id = None

        if default_namespace_uri is not None:
            self.default_namespace_uri = default_namespace_uri

        if channel is None:
            cs = GRPCChannelSingleton()
            channel = cs.channel
        
        self.namespace_if = base_if.NamespaceInterface(channel)

        # self.extradata_class_client = (
        #     lara_django_data_pb2_grpc.ExtraDataclassByIRIControllerStub(channel)
        # )
        
        self.extradata_client = lara_django_data_pb2_grpc.ExtraDataControllerStub(channel)

        # this is required by the import_file decorator, please activate if needed for file upload
        self.stub = self.extradata_client
        self.file_chunk = lara_django_data_pb2.FileChunk
        self.update_item_id = "extradata_id"

        # self.extradata_full_client = lara_django_data_pb2_grpc.ExtraDataFullControllerStub(
        #     channel
        # )

    @import_file(relation_resolver=lambda x: x)
    #@create_file  # activate if needed for file upload
    #@create_image  # activate if needed for image upload
    async def create(self,  extradata:  list[data_dm.ExtraData] = None,  ids_only: bool = False, namespace_uri: str = None) -> Union[list[str], list[data_dm.ExtraData]]:
        # TODO: only retrieve default_namespace_id if not already retrieved and namespace_uri is None
        self.namespace_id = None
        # extradataclass_id = None
        if namespace_uri is None and self.default_namespace_uri is not None:
            namespace_uri = self.default_namespace_uri
        if namespace_uri is None:
            raise ValueError("No namespace URI is given.")
        try:
            self.namespace_id = await self.namespace_if.retrieve_id(namespace_uri=namespace_uri)
        except Exception as e:
            logging.error(f"Error retrieving namespace_id: {e}")
        
        # some sample code for retrieving a class IRI and adding namespace and class to the model
        # if extradata_class_iri is None:
        #     raise ValueError("No sample class IRI is given.")
        # try:
        #     res = await self.extradata_class_client.Retrieve(
        #         lara_django_data_pb2.ExtraDataclassRetrieveRequest(iri=extradata_class_iri)
        #     )
        #     extradataclass_id = res.extradataclass_id 
        # except Exception as e:
        #     logging.error(f"Error retrieving extradataclass_id: {e}")
        # for extradata in extradatas:
        #     extradata.namespace = self.namespace_id
        #     extradata.extradata_class = extradataclass_id

        try:
            create_coroutines = ( self.extradata_client.Create(lara_django_data_pb2.ExtraDataRequest(**extradata.model_dump())) for extradata in extradata )
            res = await asyncio.gather(*create_coroutines)
            if ids_only:
                return [item.extradata_id for item in res]
            else:
                return res

        except Exception as e:
            logging.error(f"Error creating extradata: {e}")

    @export_file
    async def retrieve(
        self, 
        extradata_id: str = None,
        extradata_name: str = None,
        #extradata_name_full: str = None,
        filter_dict: dict = None,
        raw : bool = False
        ) -> list[data_dm.ExtraData]:
        filter_list = []
        results_list = []
        if  extradata_id is not None:
            try:
                res =  await self.extradata_client.Retrieve(
                    lara_django_data_pb2.ExtraDataRetrieveRequest(extradata_id=extradata_id) )
                if raw:
                    results_list.append(res)
                else:
                    results_list.append( data_dm.ExtraData(**MessageToDict(res, preserving_proto_field_name=True)) )
            except Exception as e:
                logging.error(f"Error retrieving extradata_id: {e}")

        if extradata_name is not None:
            filter_list.append({"name": extradata_name})
        # if extradata_name_full is not None:
        #     filter_list.append({"name_full": extradata_name_full})
        if filter_dict is not None:
            filter_list.append(filter_dict)

        for filter_dict in filter_list:
            metadata = (("filters", (json.dumps(filter_dict))),)
            try:
                res = await self.extradata_client.List(
                        lara_django_data_pb2.ExtraDataListRequest(), metadata=metadata
                      )
                if raw:
                      results_list += res.results
                else:
                    # a queue could be used here to speed up the retrieval
                    results = res.results
                    results_list += [ data_dm.ExtraData(**MessageToDict(res, preserving_proto_field_name=True)) for res in results ]
            except Exception as e:
                logging.error(f"Error retrieving extradata_name: {e}")

        return results_list

    #@id_cache
    async def retrieve_id(self, 
                          extradata_name: str = None,
                          extradata_name_full: str = None,
                          iri: str = None,) -> str:
        if extradata_name is not None:
            filter_dict = {"name": extradata_name}
        elif extradata_name_full is not None:
            filter_dict = {"name_full": extradata_name_full}
        elif iri is not None:
            filter_dict = {"iri": iri}
            metadata = (("filters", (json.dumps(filter_dict))),)
            try:
                res = await self.extradata_client.List(
                    lara_django_data_pb2.ExtraDataListRequest(), metadata=metadata
                )
                results = res.results
            except Exception as e:
                logging.error(f"Error retrieving extradata_name: {e}")
            if len(results) > 0 and len(results) < 2:
                return results[0].extradata_id
            else:
                raise ValueError(f"Error retrieving extradata_id - no or too many results found.")
            
        
    async def list_items(self, filter_dict: dict = None, ids_only: bool = False) -> list[str]:
        if filter_dict is None:
            res = await self.extradata_client.List(lara_django_data_pb2.ExtraDataListRequest())
        else:
            metadata = (("filters", (json.dumps(filter_dict))),)
            res = await self.extradata_client.List(
                lara_django_data_pb2.ExtraDataListRequest(), metadata=metadata
            )
        if res is not None and ids_only:
            return [item.extradata_id for item in res.results]
        else:
            return res.results
            

    async def list_full(self, filter_dict: dict = None) :
        if self.extradata_full_client is None:
            raise ValueError("No full client available.")
        if filter_dict is None:
            return await self.extradata_full_client.List(
                lara_django_data_pb2.ExtraDataFullListRequest()
            )
        else:
            metadata = (("filters", (json.dumps(filter_dict))),)
            return await self.extradata_full_client.List(
                lara_django_data_pb2.ExtraDataFullListRequest(), metadata=metadata
            )

    @import_file(relation_resolver=lambda x: x)
    # @update_image
    # @update_file
    async def update(self, extradata : data_dm.ExtraData = None) -> None:
        try:
            await self.extradata_client.Update(
                lara_django_data_pb2.ExtraDataRequest(**extradata.model_dump()
            ))
        except Exception as e:
            logging.error(f"Error updating extradata_id: {e}")

    async def delete(self, id_list: list[str] = None, filter_dict: dict = None) -> None:
        if filter_dict is not None:
            id_list = await self.list_items(filter_dict=filter_dict, ids_only=True)
    
        try:
            delete_coroutines = ( self.extradata_client.Destroy(lara_django_data_pb2.ExtraDataDestroyRequest(extradata_id=id)) for id in id_list )
            await asyncio.gather(*delete_coroutines)
            
        except Exception as e:
            logging.error(f"Error deleting extradata_id: {e}")

#_________________  BlockchainHashes  ______________________


class BlockchainHashesInterface:
    def __init__(self, channel: grpc.Channel = None, default_namespace_uri : str = None) -> None:
        self.default_namespace_uri = None
        self.default_namespace_id = None

        if default_namespace_uri is not None:
            self.default_namespace_uri = default_namespace_uri

        if channel is None:
            cs = GRPCChannelSingleton()
            channel = cs.channel
        
        self.namespace_if = base_if.NamespaceInterface(channel)

        # self.blockchainhashes_class_client = (
        #     lara_django_data_pb2_grpc.BlockchainHashesclassByIRIControllerStub(channel)
        # )
        
        self.blockchainhashes_client = lara_django_data_pb2_grpc.BlockchainHashesControllerStub(channel)

        # this is required by the import_file decorator, please activate if needed for file upload
        # self.stub = self.blockchainhashes_client
        # self.file_chunk = lara_django_data_pb2.FileChunk
        # self.update_item_id = "blockchainhashes_id"

        # self.blockchainhashes_full_client = lara_django_data_pb2_grpc.BlockchainHashesFullControllerStub(
        #     channel
        # )

    @import_file(relation_resolver=lambda x: x)
    #@create_file  # activate if needed for file upload
    #@create_image  # activate if needed for image upload
    async def create(self,  blockchainhashes:  list[data_dm.BlockchainHashes] = None,  ids_only: bool = False, namespace_uri: str = None) -> Union[list[str], list[data_dm.BlockchainHashes]]:
        # TODO: only retrieve default_namespace_id if not already retrieved and namespace_uri is None
        self.namespace_id = None
        # blockchainhashesclass_id = None
        if namespace_uri is None and self.default_namespace_uri is not None:
            namespace_uri = self.default_namespace_uri
        if namespace_uri is None:
            raise ValueError("No namespace URI is given.")
        try:
            self.namespace_id = await self.namespace_if.retrieve_id(namespace_uri=namespace_uri)
        except Exception as e:
            logging.error(f"Error retrieving namespace_id: {e}")
        
        # some sample code for retrieving a class IRI and adding namespace and class to the model
        # if blockchainhashes_class_iri is None:
        #     raise ValueError("No sample class IRI is given.")
        # try:
        #     res = await self.blockchainhashes_class_client.Retrieve(
        #         lara_django_data_pb2.BlockchainHashesclassRetrieveRequest(iri=blockchainhashes_class_iri)
        #     )
        #     blockchainhashesclass_id = res.blockchainhashesclass_id 
        # except Exception as e:
        #     logging.error(f"Error retrieving blockchainhashesclass_id: {e}")
        # for blockchainhashes in blockchainhashess:
        #     blockchainhashes.namespace = self.namespace_id
        #     blockchainhashes.blockchainhashes_class = blockchainhashesclass_id

        try:
            create_coroutines = ( self.blockchainhashes_client.Create(lara_django_data_pb2.BlockchainHashesRequest(**blockchainhashes.model_dump())) for blockchainhashes in blockchainhashes )
            res = await asyncio.gather(*create_coroutines)
            if ids_only:
                return [item.blockchainhashes_id for item in res]
            else:
                return res

        except Exception as e:
            logging.error(f"Error creating blockchainhashes: {e}")

    @export_file
    async def retrieve(
        self, 
        blockchainhashes_id: str = None,
        blockchainhashes_name: str = None,
        #blockchainhashes_name_full: str = None,
        filter_dict: dict = None,
        raw : bool = False
        ) -> list[data_dm.BlockchainHashes]:
        filter_list = []
        results_list = []
        if  blockchainhashes_id is not None:
            try:
                res =  await self.blockchainhashes_client.Retrieve(
                    lara_django_data_pb2.BlockchainHashesRetrieveRequest(blockchainhashes_id=blockchainhashes_id) )
                if raw:
                    results_list.append(res)
                else:
                    results_list.append( data_dm.BlockchainHashes(**MessageToDict(res, preserving_proto_field_name=True)) )
            except Exception as e:
                logging.error(f"Error retrieving blockchainhashes_id: {e}")

        if blockchainhashes_name is not None:
            filter_list.append({"name": blockchainhashes_name})
        # if blockchainhashes_name_full is not None:
        #     filter_list.append({"name_full": blockchainhashes_name_full})
        if filter_dict is not None:
            filter_list.append(filter_dict)

        for filter_dict in filter_list:
            metadata = (("filters", (json.dumps(filter_dict))),)
            try:
                res = await self.blockchainhashes_client.List(
                        lara_django_data_pb2.BlockchainHashesListRequest(), metadata=metadata
                      )
                if raw:
                      results_list += res.results
                else:
                    # a queue could be used here to speed up the retrieval
                    results = res.results
                    results_list += [ data_dm.BlockchainHashes(**MessageToDict(res, preserving_proto_field_name=True)) for res in results ]
            except Exception as e:
                logging.error(f"Error retrieving blockchainhashes_name: {e}")

        return results_list

    #@id_cache
    async def retrieve_id(self, 
                          blockchainhashes_name: str = None,
                          blockchainhashes_name_full: str = None,
                          iri: str = None,) -> str:
        if blockchainhashes_name is not None:
            filter_dict = {"name": blockchainhashes_name}
        elif blockchainhashes_name_full is not None:
            filter_dict = {"name_full": blockchainhashes_name_full}
        elif iri is not None:
            filter_dict = {"iri": iri}
            metadata = (("filters", (json.dumps(filter_dict))),)
            try:
                res = await self.blockchainhashes_client.List(
                    lara_django_data_pb2.BlockchainHashesListRequest(), metadata=metadata
                )
                results = res.results
            except Exception as e:
                logging.error(f"Error retrieving blockchainhashes_name: {e}")
            if len(results) > 0 and len(results) < 2:
                return results[0].blockchainhashes_id
            else:
                raise ValueError(f"Error retrieving blockchainhashes_id - no or too many results found.")
            
        
    async def list_items(self, filter_dict: dict = None, ids_only: bool = False) -> list[str]:
        if filter_dict is None:
            res = await self.blockchainhashes_client.List(lara_django_data_pb2.BlockchainHashesListRequest())
        else:
            metadata = (("filters", (json.dumps(filter_dict))),)
            res = await self.blockchainhashes_client.List(
                lara_django_data_pb2.BlockchainHashesListRequest(), metadata=metadata
            )
        if res is not None and ids_only:
            return [item.blockchainhashes_id for item in res.results]
        else:
            return res.results
            

    async def list_full(self, filter_dict: dict = None) :
        if self.blockchainhashes_full_client is None:
            raise ValueError("No full client available.")
        if filter_dict is None:
            return await self.blockchainhashes_full_client.List(
                lara_django_data_pb2.BlockchainHashesFullListRequest()
            )
        else:
            metadata = (("filters", (json.dumps(filter_dict))),)
            return await self.blockchainhashes_full_client.List(
                lara_django_data_pb2.BlockchainHashesFullListRequest(), metadata=metadata
            )

    @import_file(relation_resolver=lambda x: x)
    # @update_image
    # @update_file
    async def update(self, blockchainhashes : data_dm.BlockchainHashes = None) -> None:
        try:
            await self.blockchainhashes_client.Update(
                lara_django_data_pb2.BlockchainHashesRequest(**blockchainhashes.model_dump()
            ))
        except Exception as e:
            logging.error(f"Error updating blockchainhashes_id: {e}")

    async def delete(self, id_list: list[str] = None, filter_dict: dict = None) -> None:
        if filter_dict is not None:
            id_list = await self.list_items(filter_dict=filter_dict, ids_only=True)
    
        try:
            delete_coroutines = ( self.blockchainhashes_client.Destroy(lara_django_data_pb2.BlockchainHashesDestroyRequest(blockchainhashes_id=id)) for id in id_list )
            await asyncio.gather(*delete_coroutines)
            
        except Exception as e:
            logging.error(f"Error deleting blockchainhashes_id: {e}")

#_________________  Visualisation  ______________________


class VisualisationInterface:
    def __init__(self, channel: grpc.Channel = None, default_namespace_uri : str = None) -> None:
        self.default_namespace_uri = None
        self.default_namespace_id = None

        if default_namespace_uri is not None:
            self.default_namespace_uri = default_namespace_uri

        if channel is None:
            cs = GRPCChannelSingleton()
            channel = cs.channel
        
        self.namespace_if = base_if.NamespaceInterface(channel)

        # self.visualisation_class_client = (
        #     lara_django_data_pb2_grpc.VisualisationclassByIRIControllerStub(channel)
        # )
        
        self.visualisation_client = lara_django_data_pb2_grpc.VisualisationControllerStub(channel)

        # this is required by the import_file decorator, please activate if needed for file upload
        # self.stub = self.visualisation_client
        # self.file_chunk = lara_django_data_pb2.FileChunk
        # self.update_item_id = "visualisation_id"

        # self.visualisation_full_client = lara_django_data_pb2_grpc.VisualisationFullControllerStub(
        #     channel
        # )

    @import_file(relation_resolver=lambda x: x)
    #@create_file  # activate if needed for file upload
    #@create_image  # activate if needed for image upload
    async def create(self,  visualisations:  list[data_dm.Visualisation] = None,  ids_only: bool = False, namespace_uri: str = None) -> Union[list[str], list[data_dm.Visualisation]]:
        # TODO: only retrieve default_namespace_id if not already retrieved and namespace_uri is None
        self.namespace_id = None
        # visualisationclass_id = None
        if namespace_uri is None and self.default_namespace_uri is not None:
            namespace_uri = self.default_namespace_uri
        if namespace_uri is None:
            raise ValueError("No namespace URI is given.")
        try:
            self.namespace_id = await self.namespace_if.retrieve_id(namespace_uri=namespace_uri)
        except Exception as e:
            logging.error(f"Error retrieving namespace_id: {e}")
        
        # some sample code for retrieving a class IRI and adding namespace and class to the model
        # if visualisation_class_iri is None:
        #     raise ValueError("No sample class IRI is given.")
        # try:
        #     res = await self.visualisation_class_client.Retrieve(
        #         lara_django_data_pb2.VisualisationclassRetrieveRequest(iri=visualisation_class_iri)
        #     )
        #     visualisationclass_id = res.visualisationclass_id 
        # except Exception as e:
        #     logging.error(f"Error retrieving visualisationclass_id: {e}")
        # for visualisation in visualisations:
        #     visualisation.namespace = self.namespace_id
        #     visualisation.visualisation_class = visualisationclass_id

        try:
            create_coroutines = ( self.visualisation_client.Create(lara_django_data_pb2.VisualisationRequest(**visualisation.model_dump())) for visualisation in visualisations )
            res = await asyncio.gather(*create_coroutines)
            if ids_only:
                return [item.visualisation_id for item in res]
            else:
                return res

        except Exception as e:
            logging.error(f"Error creating visualisation: {e}")

    @export_file
    async def retrieve(
        self, 
        visualisation_id: str = None,
        visualisation_name: str = None,
        #visualisation_name_full: str = None,
        filter_dict: dict = None,
        raw : bool = False
        ) -> list[data_dm.Visualisation]:
        filter_list = []
        results_list = []
        if  visualisation_id is not None:
            try:
                res =  await self.visualisation_client.Retrieve(
                    lara_django_data_pb2.VisualisationRetrieveRequest(visualisation_id=visualisation_id) )
                if raw:
                    results_list.append(res)
                else:
                    results_list.append( data_dm.Visualisation(**MessageToDict(res, preserving_proto_field_name=True)) )
            except Exception as e:
                logging.error(f"Error retrieving visualisation_id: {e}")

        if visualisation_name is not None:
            filter_list.append({"name": visualisation_name})
        # if visualisation_name_full is not None:
        #     filter_list.append({"name_full": visualisation_name_full})
        if filter_dict is not None:
            filter_list.append(filter_dict)

        for filter_dict in filter_list:
            metadata = (("filters", (json.dumps(filter_dict))),)
            try:
                res = await self.visualisation_client.List(
                        lara_django_data_pb2.VisualisationListRequest(), metadata=metadata
                      )
                if raw:
                      results_list += res.results
                else:
                    # a queue could be used here to speed up the retrieval
                    results = res.results
                    results_list += [ data_dm.Visualisation(**MessageToDict(res, preserving_proto_field_name=True)) for res in results ]
            except Exception as e:
                logging.error(f"Error retrieving visualisation_name: {e}")

        return results_list

    #@id_cache
    async def retrieve_id(self, 
                          visualisation_name: str = None,
                          visualisation_name_full: str = None,
                          iri: str = None,) -> str:
        if visualisation_name is not None:
            filter_dict = {"name": visualisation_name}
        elif visualisation_name_full is not None:
            filter_dict = {"name_full": visualisation_name_full}
        elif iri is not None:
            filter_dict = {"iri": iri}
            metadata = (("filters", (json.dumps(filter_dict))),)
            try:
                res = await self.visualisation_client.List(
                    lara_django_data_pb2.VisualisationListRequest(), metadata=metadata
                )
                results = res.results
            except Exception as e:
                logging.error(f"Error retrieving visualisation_name: {e}")
            if len(results) > 0 and len(results) < 2:
                return results[0].visualisation_id
            else:
                raise ValueError(f"Error retrieving visualisation_id - no or too many results found.")
            
        
    async def list_items(self, filter_dict: dict = None, ids_only: bool = False) -> list[str]:
        if filter_dict is None:
            res = await self.visualisation_client.List(lara_django_data_pb2.VisualisationListRequest())
        else:
            metadata = (("filters", (json.dumps(filter_dict))),)
            res = await self.visualisation_client.List(
                lara_django_data_pb2.VisualisationListRequest(), metadata=metadata
            )
        if res is not None and ids_only:
            return [item.visualisation_id for item in res.results]
        else:
            return res.results
            

    async def list_full(self, filter_dict: dict = None) :
        if self.visualisation_full_client is None:
            raise ValueError("No full client available.")
        if filter_dict is None:
            return await self.visualisation_full_client.List(
                lara_django_data_pb2.VisualisationFullListRequest()
            )
        else:
            metadata = (("filters", (json.dumps(filter_dict))),)
            return await self.visualisation_full_client.List(
                lara_django_data_pb2.VisualisationFullListRequest(), metadata=metadata
            )

    @import_file(relation_resolver=lambda x: x)
    # @update_image
    # @update_file
    async def update(self, visualisation : data_dm.Visualisation = None) -> None:
        try:
            await self.visualisation_client.Update(
                lara_django_data_pb2.VisualisationRequest(**visualisation.model_dump()
            ))
        except Exception as e:
            logging.error(f"Error updating visualisation_id: {e}")

    async def delete(self, id_list: list[str] = None, filter_dict: dict = None) -> None:
        if filter_dict is not None:
            id_list = await self.list_items(filter_dict=filter_dict, ids_only=True)
    
        try:
            delete_coroutines = ( self.visualisation_client.Destroy(lara_django_data_pb2.VisualisationDestroyRequest(visualisation_id=id)) for id in id_list )
            await asyncio.gather(*delete_coroutines)
            
        except Exception as e:
            logging.error(f"Error deleting visualisation_id: {e}")

#_________________  Data  ______________________


class DataInterface:
    def __init__(self, channel: grpc.Channel = None, default_namespace_uri : str = None) -> None:
        self.default_namespace_uri = None
        self.default_namespace_id = None

        if default_namespace_uri is not None:
            self.default_namespace_uri = default_namespace_uri

        if channel is None:
            cs = GRPCChannelSingleton()
            channel = cs.channel
        
        self.namespace_if = base_if.NamespaceInterface(channel)

        # self.data_class_client = (
        #     lara_django_data_pb2_grpc.DataclassByIRIControllerStub(channel)
        # )
        
        self.data_client = lara_django_data_pb2_grpc.DataControllerStub(channel)

        # this is required by the import_file decorator, please activate if needed for file upload
        self.stub = self.data_client
        self.file_chunk = lara_django_data_pb2.FileChunk
        self.update_item_id = "data_id"

        # self.data_full_client = lara_django_data_pb2_grpc.DataFullControllerStub(
        #     channel
        # )

    @import_file(relation_resolver=lambda x: x)
    @create_file  # activate if needed for file upload
    #@create_image  # activate if needed for image upload
    async def create(self,  data:  list[data_dm.Data] = None,  ids_only: bool = False, namespace_uri: str = None) -> Union[list[str], list[data_dm.Data]]:
        # TODO: only retrieve default_namespace_id if not already retrieved and namespace_uri is None
        self.namespace_id = None
        # dataclass_id = None
        if namespace_uri is None and self.default_namespace_uri is not None:
            namespace_uri = self.default_namespace_uri
        if namespace_uri is None:
            raise ValueError("No namespace URI is given.")
        try:
            self.namespace_id = await self.namespace_if.retrieve_id(namespace_uri=namespace_uri)
        except Exception as e:
            logging.error(f"Error retrieving namespace_id: {e}")
        
        # some sample code for retrieving a class IRI and adding namespace and class to the model
        # if data_class_iri is None:
        #     raise ValueError("No sample class IRI is given.")
        # try:
        #     res = await self.data_class_client.Retrieve(
        #         lara_django_data_pb2.DataclassRetrieveRequest(iri=data_class_iri)
        #     )
        #     dataclass_id = res.dataclass_id 
        # except Exception as e:
        #     logging.error(f"Error retrieving dataclass_id: {e}")

        try:
            coroutines = []
            for datum in data:
                datum.namespace = self.namespace_id
                #     datum.data_class = dataclass_id
                datum_dict = datum.model_dump()

                try:
                    data_struct = Struct()

                    # string to json
                    data_json = json.loads(datum_dict.get("data_json"))
                    data_struct.update(data_json)
                    datum_dict["data_json"] = data_struct
                except Exception as e:
                    logging.error(f"Error converting data_json to Struct: {e}")
                
                # convert metadata to struct

                try:
                    metadata_struct = Struct()
                    metadata_json = json.loads(datum_dict.get("metadata"))
                    metadata_struct.update(metadata_json)
                    datum_dict["metadata"] = metadata_struct

                except Exception as e:
                    logging.error(f"Error converting metadata to Struct: {e}")

                #create_coroutines = ( self.data_client.Create(lara_django_data_pb2.DataRequest(**data.model_dump())) for data in data )

                coroutines.append(self.data_client.Create(lara_django_data_pb2.DataRequest(**datum_dict)))

            res = await asyncio.gather(*coroutines)
            if ids_only:
                return [item.data_id for item in res]
            else:
                return res

        except Exception as e:
            logging.error(f"Error creating data: {e}")

    @export_file
    async def retrieve(
        self, 
        data_id: str = None,
        data_name: str = None,
        #data_name_full: str = None,
        filter_dict: dict = None,
        raw : bool = False
        ) -> list[data_dm.Data]:
        filter_list = []
        results_list = []
        if  data_id is not None:
            try:
                res =  await self.data_client.Retrieve(
                    lara_django_data_pb2.DataRetrieveRequest(data_id=data_id) )
                if raw:
                    results_list.append(res)
                else:
                    results_list.append( data_dm.Data(**MessageToDict(res, preserving_proto_field_name=True)) )
            except Exception as e:
                logging.error(f"Error retrieving data_id: {e}")

        if data_name is not None:
            filter_list.append({"name": data_name})
        # if data_name_full is not None:
        #     filter_list.append({"name_full": data_name_full})
        if filter_dict is not None:
            filter_list.append(filter_dict)

        for filter_dict in filter_list:
            metadata = (("filters", (json.dumps(filter_dict))),)
            try:
                res = await self.data_client.List(
                        lara_django_data_pb2.DataListRequest(), metadata=metadata
                      )
                if raw:
                      results_list += res.results
                else:
                    # a queue could be used here to speed up the retrieval
                    results = res.results
                    results_list += [ data_dm.Data(**MessageToDict(res, preserving_proto_field_name=True)) for res in results ]
            except Exception as e:
                logging.error(f"Error retrieving data_name: {e}")

        return results_list

    #@id_cache
    async def retrieve_id(self, 
                          data_name: str = None,
                          data_name_full: str = None,
                          iri: str = None,) -> str:
        if data_name is not None:
            filter_dict = {"name": data_name}
        elif data_name_full is not None:
            filter_dict = {"name_full": data_name_full}
        elif iri is not None:
            filter_dict = {"iri": iri}
            metadata = (("filters", (json.dumps(filter_dict))),)
            try:
                res = await self.data_client.List(
                    lara_django_data_pb2.DataListRequest(), metadata=metadata
                )
                results = res.results
            except Exception as e:
                logging.error(f"Error retrieving data_name: {e}")
            if len(results) > 0 and len(results) < 2:
                return results[0].data_id
            else:
                raise ValueError(f"Error retrieving data_id - no or too many results found.")
            
        
    async def list_items(self, filter_dict: dict = None, ids_only: bool = False) -> list[str]:
        if filter_dict is None:
            res = await self.data_client.List(lara_django_data_pb2.DataListRequest())
        else:
            metadata = (("filters", (json.dumps(filter_dict))),)
            res = await self.data_client.List(
                lara_django_data_pb2.DataListRequest(), metadata=metadata
            )
        if res is not None and ids_only:
            return [item.data_id for item in res.results]
        else:
            return res.results
            

    async def list_full(self, filter_dict: dict = None) :
        if self.data_full_client is None:
            raise ValueError("No full client available.")
        if filter_dict is None:
            return await self.data_full_client.List(
                lara_django_data_pb2.DataFullListRequest()
            )
        else:
            metadata = (("filters", (json.dumps(filter_dict))),)
            return await self.data_full_client.List(
                lara_django_data_pb2.DataFullListRequest(), metadata=metadata
            )

    @import_file(relation_resolver=lambda x: x)
    # @update_image
    @update_file
    async def update(self, data : data_dm.Data = None) -> None:
        try:
            await self.data_client.Update(
                lara_django_data_pb2.DataRequest(**data.model_dump()
            ))
        except Exception as e:
            logging.error(f"Error updating data_id: {e}")

    async def delete(self, id_list: list[str] = None, filter_dict: dict = None) -> None:
        if filter_dict is not None:
            id_list = await self.list_items(filter_dict=filter_dict, ids_only=True)
    
        try:
            delete_coroutines = ( self.data_client.Destroy(lara_django_data_pb2.DataDestroyRequest(data_id=id)) for id in id_list )
            await asyncio.gather(*delete_coroutines)
            
        except Exception as e:
            logging.error(f"Error deleting data_id: {e}")

#_________________  DataSubset  ______________________


class DataSubsetInterface:
    def __init__(self, channel: grpc.Channel = None, default_namespace_uri : str = None) -> None:
        self.default_namespace_uri = None
        self.default_namespace_id = None

        if default_namespace_uri is not None:
            self.default_namespace_uri = default_namespace_uri

        if channel is None:
            cs = GRPCChannelSingleton()
            channel = cs.channel
        
        self.namespace_if = base_if.NamespaceInterface(channel)

        # self.datasubset_class_client = (
        #     lara_django_data_pb2_grpc.DataSubsetclassByIRIControllerStub(channel)
        # )
        
        self.datasubset_client = lara_django_data_pb2_grpc.DataSubsetControllerStub(channel)

        # this is required by the import_file decorator, please activate if needed for file upload
        # self.stub = self.datasubset_client
        # self.file_chunk = lara_django_data_pb2.FileChunk
        # self.update_item_id = "datasubset_id"

        # self.datasubset_full_client = lara_django_data_pb2_grpc.DataSubsetFullControllerStub(
        #     channel
        # )

    @import_file(relation_resolver=lambda x: x)
    #@create_file  # activate if needed for file upload
    #@create_image  # activate if needed for image upload
    async def create(self,  datasubsets:  list[data_dm.DataSubset] = None,  ids_only: bool = False, namespace_uri: str = None) -> Union[list[str], list[data_dm.DataSubset]]:
        # TODO: only retrieve default_namespace_id if not already retrieved and namespace_uri is None
        self.namespace_id = None
        # datasubsetclass_id = None
        if namespace_uri is None and self.default_namespace_uri is not None:
            namespace_uri = self.default_namespace_uri
        if namespace_uri is None:
            raise ValueError("No namespace URI is given.")
        try:
            self.namespace_id = await self.namespace_if.retrieve_id(namespace_uri=namespace_uri)
        except Exception as e:
            logging.error(f"Error retrieving namespace_id: {e}")
        
        # some sample code for retrieving a class IRI and adding namespace and class to the model
        # if datasubset_class_iri is None:
        #     raise ValueError("No sample class IRI is given.")
        # try:
        #     res = await self.datasubset_class_client.Retrieve(
        #         lara_django_data_pb2.DataSubsetclassRetrieveRequest(iri=datasubset_class_iri)
        #     )
        #     datasubsetclass_id = res.datasubsetclass_id 
        # except Exception as e:
        #     logging.error(f"Error retrieving datasubsetclass_id: {e}")
        # for datasubset in datasubsets:
        #     datasubset.namespace = self.namespace_id
        #     datasubset.datasubset_class = datasubsetclass_id

        try:
            create_coroutines = ( self.datasubset_client.Create(lara_django_data_pb2.DataSubsetRequest(**datasubset.model_dump())) for datasubset in datasubsets )
            res = await asyncio.gather(*create_coroutines)
            if ids_only:
                return [item.datasubset_id for item in res]
            else:
                return res

        except Exception as e:
            logging.error(f"Error creating datasubset: {e}")

    @export_file
    async def retrieve(
        self, 
        datasubset_id: str = None,
        datasubset_name: str = None,
        #datasubset_name_full: str = None,
        filter_dict: dict = None,
        raw : bool = False
        ) -> list[data_dm.DataSubset]:
        filter_list = []
        results_list = []
        if  datasubset_id is not None:
            try:
                res =  await self.datasubset_client.Retrieve(
                    lara_django_data_pb2.DataSubsetRetrieveRequest(datasubset_id=datasubset_id) )
                if raw:
                    results_list.append(res)
                else:
                    results_list.append( data_dm.DataSubset(**MessageToDict(res, preserving_proto_field_name=True)) )
            except Exception as e:
                logging.error(f"Error retrieving datasubset_id: {e}")

        if datasubset_name is not None:
            filter_list.append({"name": datasubset_name})
        # if datasubset_name_full is not None:
        #     filter_list.append({"name_full": datasubset_name_full})
        if filter_dict is not None:
            filter_list.append(filter_dict)

        for filter_dict in filter_list:
            metadata = (("filters", (json.dumps(filter_dict))),)
            try:
                res = await self.datasubset_client.List(
                        lara_django_data_pb2.DataSubsetListRequest(), metadata=metadata
                      )
                if raw:
                      results_list += res.results
                else:
                    # a queue could be used here to speed up the retrieval
                    results = res.results
                    results_list += [ data_dm.DataSubset(**MessageToDict(res, preserving_proto_field_name=True)) for res in results ]
            except Exception as e:
                logging.error(f"Error retrieving datasubset_name: {e}")

        return results_list

    #@id_cache
    async def retrieve_id(self, 
                          datasubset_name: str = None,
                          datasubset_name_full: str = None,
                          iri: str = None,) -> str:
        if datasubset_name is not None:
            filter_dict = {"name": datasubset_name}
        elif datasubset_name_full is not None:
            filter_dict = {"name_full": datasubset_name_full}
        elif iri is not None:
            filter_dict = {"iri": iri}
            metadata = (("filters", (json.dumps(filter_dict))),)
            try:
                res = await self.datasubset_client.List(
                    lara_django_data_pb2.DataSubsetListRequest(), metadata=metadata
                )
                results = res.results
            except Exception as e:
                logging.error(f"Error retrieving datasubset_name: {e}")
            if len(results) > 0 and len(results) < 2:
                return results[0].datasubset_id
            else:
                raise ValueError(f"Error retrieving datasubset_id - no or too many results found.")
            
        
    async def list_items(self, filter_dict: dict = None, ids_only: bool = False) -> list[str]:
        if filter_dict is None:
            res = await self.datasubset_client.List(lara_django_data_pb2.DataSubsetListRequest())
        else:
            metadata = (("filters", (json.dumps(filter_dict))),)
            res = await self.datasubset_client.List(
                lara_django_data_pb2.DataSubsetListRequest(), metadata=metadata
            )
        if res is not None and ids_only:
            return [item.datasubset_id for item in res.results]
        else:
            return res.results
            

    async def list_full(self, filter_dict: dict = None) :
        if self.datasubset_full_client is None:
            raise ValueError("No full client available.")
        if filter_dict is None:
            return await self.datasubset_full_client.List(
                lara_django_data_pb2.DataSubsetFullListRequest()
            )
        else:
            metadata = (("filters", (json.dumps(filter_dict))),)
            return await self.datasubset_full_client.List(
                lara_django_data_pb2.DataSubsetFullListRequest(), metadata=metadata
            )

    @import_file(relation_resolver=lambda x: x)
    # @update_image
    # @update_file
    async def update(self, datasubset : data_dm.DataSubset = None) -> None:
        try:
            await self.datasubset_client.Update(
                lara_django_data_pb2.DataSubsetRequest(**datasubset.model_dump()
            ))
        except Exception as e:
            logging.error(f"Error updating datasubset_id: {e}")

    async def delete(self, id_list: list[str] = None, filter_dict: dict = None) -> None:
        if filter_dict is not None:
            id_list = await self.list_items(filter_dict=filter_dict, ids_only=True)
    
        try:
            delete_coroutines = ( self.datasubset_client.Destroy(lara_django_data_pb2.DataSubsetDestroyRequest(datasubset_id=id)) for id in id_list )
            await asyncio.gather(*delete_coroutines)
            
        except Exception as e:
            logging.error(f"Error deleting datasubset_id: {e}")

#_________________  Evaluation  ______________________


class EvaluationInterface:
    def __init__(self, channel: grpc.Channel = None, default_namespace_uri : str = None) -> None:
        self.default_namespace_uri = None
        self.default_namespace_id = None

        if default_namespace_uri is not None:
            self.default_namespace_uri = default_namespace_uri

        if channel is None:
            cs = GRPCChannelSingleton()
            channel = cs.channel
        
        self.namespace_if = base_if.NamespaceInterface(channel)

        # self.evaluation_class_client = (
        #     lara_django_data_pb2_grpc.EvaluationclassByIRIControllerStub(channel)
        # )
        
        self.evaluation_client = lara_django_data_pb2_grpc.EvaluationControllerStub(channel)

        # this is required by the import_file decorator, please activate if needed for file upload
        # self.stub = self.evaluation_client
        # self.file_chunk = lara_django_data_pb2.FileChunk
        # self.update_item_id = "evaluation_id"

        # self.evaluation_full_client = lara_django_data_pb2_grpc.EvaluationFullControllerStub(
        #     channel
        # )

    @import_file(relation_resolver=lambda x: x)
    #@create_file  # activate if needed for file upload
    #@create_image  # activate if needed for image upload
    async def create(self,  evaluations:  list[data_dm.Evaluation] = None,  ids_only: bool = False, namespace_uri: str = None) -> Union[list[str], list[data_dm.Evaluation]]:
        # TODO: only retrieve default_namespace_id if not already retrieved and namespace_uri is None
        self.namespace_id = None
        # evaluationclass_id = None
        if namespace_uri is None and self.default_namespace_uri is not None:
            namespace_uri = self.default_namespace_uri
        if namespace_uri is None:
            raise ValueError("No namespace URI is given.")
        try:
            self.namespace_id = await self.namespace_if.retrieve_id(namespace_uri=namespace_uri)
        except Exception as e:
            logging.error(f"Error retrieving namespace_id: {e}")
        
        # some sample code for retrieving a class IRI and adding namespace and class to the model
        # if evaluation_class_iri is None:
        #     raise ValueError("No sample class IRI is given.")
        # try:
        #     res = await self.evaluation_class_client.Retrieve(
        #         lara_django_data_pb2.EvaluationclassRetrieveRequest(iri=evaluation_class_iri)
        #     )
        #     evaluationclass_id = res.evaluationclass_id 
        # except Exception as e:
        #     logging.error(f"Error retrieving evaluationclass_id: {e}")
        # for evaluation in evaluations:
        #     evaluation.namespace = self.namespace_id
        #     evaluation.evaluation_class = evaluationclass_id

        try:
            create_coroutines = ( self.evaluation_client.Create(lara_django_data_pb2.EvaluationRequest(**evaluation.model_dump())) for evaluation in evaluations )
            res = await asyncio.gather(*create_coroutines)
            if ids_only:
                return [item.evaluation_id for item in res]
            else:
                return res

        except Exception as e:
            logging.error(f"Error creating evaluation: {e}")

    @export_file
    async def retrieve(
        self, 
        evaluation_id: str = None,
        evaluation_name: str = None,
        #evaluation_name_full: str = None,
        filter_dict: dict = None,
        raw : bool = False
        ) -> list[data_dm.Evaluation]:
        filter_list = []
        results_list = []
        if  evaluation_id is not None:
            try:
                res =  await self.evaluation_client.Retrieve(
                    lara_django_data_pb2.EvaluationRetrieveRequest(evaluation_id=evaluation_id) )
                if raw:
                    results_list.append(res)
                else:
                    results_list.append( data_dm.Evaluation(**MessageToDict(res, preserving_proto_field_name=True)) )
            except Exception as e:
                logging.error(f"Error retrieving evaluation_id: {e}")

        if evaluation_name is not None:
            filter_list.append({"name": evaluation_name})
        # if evaluation_name_full is not None:
        #     filter_list.append({"name_full": evaluation_name_full})
        if filter_dict is not None:
            filter_list.append(filter_dict)

        for filter_dict in filter_list:
            metadata = (("filters", (json.dumps(filter_dict))),)
            try:
                res = await self.evaluation_client.List(
                        lara_django_data_pb2.EvaluationListRequest(), metadata=metadata
                      )
                if raw:
                      results_list += res.results
                else:
                    # a queue could be used here to speed up the retrieval
                    results = res.results
                    results_list += [ data_dm.Evaluation(**MessageToDict(res, preserving_proto_field_name=True)) for res in results ]
            except Exception as e:
                logging.error(f"Error retrieving evaluation_name: {e}")

        return results_list

    #@id_cache
    async def retrieve_id(self, 
                          evaluation_name: str = None,
                          evaluation_name_full: str = None,
                          iri: str = None,) -> str:
        if evaluation_name is not None:
            filter_dict = {"name": evaluation_name}
        elif evaluation_name_full is not None:
            filter_dict = {"name_full": evaluation_name_full}
        elif iri is not None:
            filter_dict = {"iri": iri}
            metadata = (("filters", (json.dumps(filter_dict))),)
            try:
                res = await self.evaluation_client.List(
                    lara_django_data_pb2.EvaluationListRequest(), metadata=metadata
                )
                results = res.results
            except Exception as e:
                logging.error(f"Error retrieving evaluation_name: {e}")
            if len(results) > 0 and len(results) < 2:
                return results[0].evaluation_id
            else:
                raise ValueError(f"Error retrieving evaluation_id - no or too many results found.")
            
        
    async def list_items(self, filter_dict: dict = None, ids_only: bool = False) -> list[str]:
        if filter_dict is None:
            res = await self.evaluation_client.List(lara_django_data_pb2.EvaluationListRequest())
        else:
            metadata = (("filters", (json.dumps(filter_dict))),)
            res = await self.evaluation_client.List(
                lara_django_data_pb2.EvaluationListRequest(), metadata=metadata
            )
        if res is not None and ids_only:
            return [item.evaluation_id for item in res.results]
        else:
            return res.results
            

    async def list_full(self, filter_dict: dict = None) :
        if self.evaluation_full_client is None:
            raise ValueError("No full client available.")
        if filter_dict is None:
            return await self.evaluation_full_client.List(
                lara_django_data_pb2.EvaluationFullListRequest()
            )
        else:
            metadata = (("filters", (json.dumps(filter_dict))),)
            return await self.evaluation_full_client.List(
                lara_django_data_pb2.EvaluationFullListRequest(), metadata=metadata
            )

    @import_file(relation_resolver=lambda x: x)
    # @update_image
    # @update_file
    async def update(self, evaluation : data_dm.Evaluation = None) -> None:
        try:
            await self.evaluation_client.Update(
                lara_django_data_pb2.EvaluationRequest(**evaluation.model_dump()
            ))
        except Exception as e:
            logging.error(f"Error updating evaluation_id: {e}")

    async def delete(self, id_list: list[str] = None, filter_dict: dict = None) -> None:
        if filter_dict is not None:
            id_list = await self.list_items(filter_dict=filter_dict, ids_only=True)
    
        try:
            delete_coroutines = ( self.evaluation_client.Destroy(lara_django_data_pb2.EvaluationDestroyRequest(evaluation_id=id)) for id in id_list )
            await asyncio.gather(*delete_coroutines)
            
        except Exception as e:
            logging.error(f"Error deleting evaluation_id: {e}")




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: lara_django_data_grpc/v1/lara_django_data.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'lara_django_data_grpc/v1/lara_django_data.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/lara_django_data_grpc/v1/lara_django_data.proto\x12\x1clara_django.lara_django_data\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\"-\n\x12\x44\x61taDestroyRequest\x12\x17\n\x07\x64\x61ta_id\x18\x01 \x01(\tR\x06\x64\x61taId\"\x11\n\x0f\x44\x61taListRequest\"X\n\x10\x44\x61taListResponse\x12\x44\n\x07results\x18\x01 \x03(\x0b\x32*.lara_django.lara_django_data.DataResponseR\x07results\"\xd1\r\n\x18\x44\x61taPartialUpdateRequest\x12\x1c\n\x07\x64\x61ta_id\x18\x01 \x01(\tH\x00R\x06\x64\x61taId\x88\x01\x01\x12 \n\tdata_type\x18\x02 \x01(\tH\x01R\x08\x64\x61taType\x88\x01\x01\x12\"\n\nmedia_type\x18\x03 \x01(\tH\x02R\tmediaType\x88\x01\x01\x12\x1c\n\tnamespace\x18\x04 \x01(\tR\tnamespace\x12,\n\x0fmethod_instance\x18\x05 \x01(\tH\x03R\x0emethodInstance\x88\x01\x01\x12.\n\x10process_instance\x18\x06 \x01(\tH\x04R\x0fprocessInstance\x88\x01\x01\x12\x32\n\x12procedure_instance\x18\x07 \x01(\tH\x05R\x11procedureInstance\x88\x01\x01\x12\x14\n\x05users\x18\x08 \x03(\tR\x05users\x12\x16\n\x06groups\x18\t \x03(\tR\x06groups\x12&\n\x0evisualisations\x18\n \x03(\tR\x0evisualisations\x12\x1d\n\ndata_extra\x18\x0b \x03(\tR\tdataExtra\x12\x12\n\x04tags\x18\x0c \x03(\tR\x04tags\x12-\n\x12resources_external\x18\r \x03(\tR\x11resourcesExternal\x12\x33\n\x16_partial_update_fields\x18\x0e \x03(\tR\x13PartialUpdateFields\x12\x17\n\x04name\x18\x0f \x01(\tH\x06R\x04name\x88\x01\x01\x12\x1d\n\x07version\x18\x10 \x01(\tH\x07R\x07version\x88\x01\x01\x12 \n\tname_full\x18\x12 \x01(\tH\x08R\x08nameFull\x88\x01\x01\x12$\n\x0bhash_sha256\x18\x13 \x01(\tH\tR\nhashSha256\x88\x01\x01\x12,\n\x0fhash_blockchain\x18\x14 \x01(\tH\nR\x0ehashBlockchain\x88\x01\x01\x12.\n\x03\x61\x63l\x18\x15 \x01(\x0b\x32\x17.google.protobuf.StructH\x0bR\x03\x61\x63l\x88\x01\x01\x12\x38\n\x08licenses\x18\x16 \x01(\x0b\x32\x17.google.protobuf.StructH\x0cR\x08licenses\x88\x01\x01\x12.\n\x10\x64\x61tetime_created\x18\x17 \x01(\tH\rR\x0f\x64\x61tetimeCreated\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x18 \x01(\tH\x0eR\x14\x64\x61tetimeLastModified\x88\x01\x01\x12\x39\n\tdata_json\x18\x19 \x01(\x0b\x32\x17.google.protobuf.StructH\x0fR\x08\x64\x61taJson\x88\x01\x01\x12\x38\n\x08metadata\x18\x1a \x01(\x0b\x32\x17.google.protobuf.StructH\x10R\x08metadata\x88\x01\x01\x12\x15\n\x03iri\x18\x1b \x01(\tH\x11R\x03iri\x88\x01\x01\x12\x15\n\x03pid\x18\x1c \x01(\tH\x12R\x03pid\x88\x01\x01\x12\x15\n\x03\x64oi\x18\x1d \x01(\tH\x13R\x03\x64oi\x88\x01\x01\x12\x1a\n\x06pac_id\x18\x1e \x01(\tH\x14R\x05pacId\x88\x01\x01\x12\x17\n\x04\x66ile\x18\x1f \x01(\tH\x15R\x04\x66ile\x88\x01\x01\x12!\n\tthumbnail\x18  \x01(\tH\x16R\tthumbnail\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18! \x01(\tH\x17R\x0b\x64\x65scription\x88\x01\x01\x12\x1d\n\x07remarks\x18\" \x01(\tH\x18R\x07remarks\x88\x01\x01\x12&\n\x0cname_display\x18# \x01(\tH\x19R\x0bnameDisplay\x88\x01\x01\x12(\n\rsearch_vector\x18$ \x01(\tH\x1aR\x0csearchVector\x88\x01\x01\x42\n\n\x08_data_idB\x0c\n\n_data_typeB\r\n\x0b_media_typeB\x12\n\x10_method_instanceB\x13\n\x11_process_instanceB\x15\n\x13_procedure_instanceB\x07\n\x05_nameB\n\n\x08_versionB\x0c\n\n_name_fullB\x0e\n\x0c_hash_sha256B\x12\n\x10_hash_blockchainB\x06\n\x04_aclB\x0b\n\t_licensesB\x13\n\x11_datetime_createdB\x19\n\x17_datetime_last_modifiedB\x0c\n\n_data_jsonB\x0b\n\t_metadataB\x06\n\x04_iriB\x06\n\x04_pidB\x06\n\x04_doiB\t\n\x07_pac_idB\x07\n\x05_fileB\x0c\n\n_thumbnailB\x0e\n\x0c_descriptionB\n\n\x08_remarksB\x0f\n\r_name_displayB\x10\n\x0e_search_vector\"\x8f\r\n\x0b\x44\x61taRequest\x12\x1c\n\x07\x64\x61ta_id\x18\x01 \x01(\tH\x00R\x06\x64\x61taId\x88\x01\x01\x12 \n\tdata_type\x18\x02 \x01(\tH\x01R\x08\x64\x61taType\x88\x01\x01\x12\"\n\nmedia_type\x18\x03 \x01(\tH\x02R\tmediaType\x88\x01\x01\x12\x1c\n\tnamespace\x18\x04 \x01(\tR\tnamespace\x12,\n\x0fmethod_instance\x18\x05 \x01(\tH\x03R\x0emethodInstance\x88\x01\x01\x12.\n\x10process_instance\x18\x06 \x01(\tH\x04R\x0fprocessInstance\x88\x01\x01\x12\x32\n\x12procedure_instance\x18\x07 \x01(\tH\x05R\x11procedureInstance\x88\x01\x01\x12\x14\n\x05users\x18\x08 \x03(\tR\x05users\x12\x16\n\x06groups\x18\t \x03(\tR\x06groups\x12&\n\x0evisualisations\x18\n \x03(\tR\x0evisualisations\x12\x1d\n\ndata_extra\x18\x0b \x03(\tR\tdataExtra\x12\x12\n\x04tags\x18\x0c \x03(\tR\x04tags\x12-\n\x12resources_external\x18\r \x03(\tR\x11resourcesExternal\x12\x17\n\x04name\x18\x0e \x01(\tH\x06R\x04name\x88\x01\x01\x12\x1d\n\x07version\x18\x0f \x01(\tH\x07R\x07version\x88\x01\x01\x12 \n\tname_full\x18\x11 \x01(\tH\x08R\x08nameFull\x88\x01\x01\x12$\n\x0bhash_sha256\x18\x12 \x01(\tH\tR\nhashSha256\x88\x01\x01\x12,\n\x0fhash_blockchain\x18\x13 \x01(\tH\nR\x0ehashBlockchain\x88\x01\x01\x12.\n\x03\x61\x63l\x18\x14 \x01(\x0b\x32\x17.google.protobuf.StructH\x0bR\x03\x61\x63l\x88\x01\x01\x12\x38\n\x08licenses\x18\x15 \x01(\x0b\x32\x17.google.protobuf.StructH\x0cR\x08licenses\x88\x01\x01\x12.\n\x10\x64\x61tetime_created\x18\x16 \x01(\tH\rR\x0f\x64\x61tetimeCreated\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x17 \x01(\tH\x0eR\x14\x64\x61tetimeLastModified\x88\x01\x01\x12\x39\n\tdata_json\x18\x18 \x01(\x0b\x32\x17.google.protobuf.StructH\x0fR\x08\x64\x61taJson\x88\x01\x01\x12\x38\n\x08metadata\x18\x19 \x01(\x0b\x32\x17.google.protobuf.StructH\x10R\x08metadata\x88\x01\x01\x12\x15\n\x03iri\x18\x1a \x01(\tH\x11R\x03iri\x88\x01\x01\x12\x15\n\x03pid\x18\x1b \x01(\tH\x12R\x03pid\x88\x01\x01\x12\x15\n\x03\x64oi\x18\x1c \x01(\tH\x13R\x03\x64oi\x88\x01\x01\x12\x1a\n\x06pac_id\x18\x1d \x01(\tH\x14R\x05pacId\x88\x01\x01\x12\x17\n\x04\x66ile\x18\x1e \x01(\tH\x15R\x04\x66ile\x88\x01\x01\x12!\n\tthumbnail\x18\x1f \x01(\tH\x16R\tthumbnail\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18  \x01(\tH\x17R\x0b\x64\x65scription\x88\x01\x01\x12\x1d\n\x07remarks\x18! \x01(\tH\x18R\x07remarks\x88\x01\x01\x12&\n\x0cname_display\x18\" \x01(\tH\x19R\x0bnameDisplay\x88\x01\x01\x12(\n\rsearch_vector\x18# \x01(\tH\x1aR\x0csearchVector\x88\x01\x01\x42\n\n\x08_data_idB\x0c\n\n_data_typeB\r\n\x0b_media_typeB\x12\n\x10_method_instanceB\x13\n\x11_process_instanceB\x15\n\x13_procedure_instanceB\x07\n\x05_nameB\n\n\x08_versionB\x0c\n\n_name_fullB\x0e\n\x0c_hash_sha256B\x12\n\x10_hash_blockchainB\x06\n\x04_aclB\x0b\n\t_licensesB\x13\n\x11_datetime_createdB\x19\n\x17_datetime_last_modifiedB\x0c\n\n_data_jsonB\x0b\n\t_metadataB\x06\n\x04_iriB\x06\n\x04_pidB\x06\n\x04_doiB\t\n\x07_pac_idB\x07\n\x05_fileB\x0c\n\n_thumbnailB\x0e\n\x0c_descriptionB\n\n\x08_remarksB\x0f\n\r_name_displayB\x10\n\x0e_search_vector\"\x90\r\n\x0c\x44\x61taResponse\x12\x1c\n\x07\x64\x61ta_id\x18\x01 \x01(\tH\x00R\x06\x64\x61taId\x88\x01\x01\x12 \n\tdata_type\x18\x02 \x01(\tH\x01R\x08\x64\x61taType\x88\x01\x01\x12\"\n\nmedia_type\x18\x03 \x01(\tH\x02R\tmediaType\x88\x01\x01\x12\x1c\n\tnamespace\x18\x04 \x01(\tR\tnamespace\x12,\n\x0fmethod_instance\x18\x05 \x01(\tH\x03R\x0emethodInstance\x88\x01\x01\x12.\n\x10process_instance\x18\x06 \x01(\tH\x04R\x0fprocessInstance\x88\x01\x01\x12\x32\n\x12procedure_instance\x18\x07 \x01(\tH\x05R\x11procedureInstance\x88\x01\x01\x12\x14\n\x05users\x18\x08 \x03(\tR\x05users\x12\x16\n\x06groups\x18\t \x03(\tR\x06groups\x12&\n\x0evisualisations\x18\n \x03(\tR\x0evisualisations\x12\x1d\n\ndata_extra\x18\x0b \x03(\tR\tdataExtra\x12\x12\n\x04tags\x18\x0c \x03(\tR\x04tags\x12-\n\x12resources_external\x18\r \x03(\tR\x11resourcesExternal\x12\x17\n\x04name\x18\x0e \x01(\tH\x06R\x04name\x88\x01\x01\x12\x1d\n\x07version\x18\x0f \x01(\tH\x07R\x07version\x88\x01\x01\x12 \n\tname_full\x18\x11 \x01(\tH\x08R\x08nameFull\x88\x01\x01\x12$\n\x0bhash_sha256\x18\x12 \x01(\tH\tR\nhashSha256\x88\x01\x01\x12,\n\x0fhash_blockchain\x18\x13 \x01(\tH\nR\x0ehashBlockchain\x88\x01\x01\x12.\n\x03\x61\x63l\x18\x14 \x01(\x0b\x32\x17.google.protobuf.StructH\x0bR\x03\x61\x63l\x88\x01\x01\x12\x38\n\x08licenses\x18\x15 \x01(\x0b\x32\x17.google.protobuf.StructH\x0cR\x08licenses\x88\x01\x01\x12.\n\x10\x64\x61tetime_created\x18\x16 \x01(\tH\rR\x0f\x64\x61tetimeCreated\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x17 \x01(\tH\x0eR\x14\x64\x61tetimeLastModified\x88\x01\x01\x12\x39\n\tdata_json\x18\x18 \x01(\x0b\x32\x17.google.protobuf.StructH\x0fR\x08\x64\x61taJson\x88\x01\x01\x12\x38\n\x08metadata\x18\x19 \x01(\x0b\x32\x17.google.protobuf.StructH\x10R\x08metadata\x88\x01\x01\x12\x15\n\x03iri\x18\x1a \x01(\tH\x11R\x03iri\x88\x01\x01\x12\x15\n\x03pid\x18\x1b \x01(\tH\x12R\x03pid\x88\x01\x01\x12\x15\n\x03\x64oi\x18\x1c \x01(\tH\x13R\x03\x64oi\x88\x01\x01\x12\x1a\n\x06pac_id\x18\x1d \x01(\tH\x14R\x05pacId\x88\x01\x01\x12\x17\n\x04\x66ile\x18\x1e \x01(\tH\x15R\x04\x66ile\x88\x01\x01\x12!\n\tthumbnail\x18\x1f \x01(\tH\x16R\tthumbnail\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18  \x01(\tH\x17R\x0b\x64\x65scription\x88\x01\x01\x12\x1d\n\x07remarks\x18! \x01(\tH\x18R\x07remarks\x88\x01\x01\x12&\n\x0cname_display\x18\" \x01(\tH\x19R\x0bnameDisplay\x88\x01\x01\x12(\n\rsearch_vector\x18# \x01(\tH\x1aR\x0csearchVector\x88\x01\x01\x42\n\n\x08_data_idB\x0c\n\n_data_typeB\r\n\x0b_media_typeB\x12\n\x10_method_instanceB\x13\n\x11_process_instanceB\x15\n\x13_procedure_instanceB\x07\n\x05_nameB\n\n\x08_versionB\x0c\n\n_name_fullB\x0e\n\x0c_hash_sha256B\x12\n\x10_hash_blockchainB\x06\n\x04_aclB\x0b\n\t_licensesB\x13\n\x11_datetime_createdB\x19\n\x17_datetime_last_modifiedB\x0c\n\n_data_jsonB\x0b\n\t_metadataB\x06\n\x04_iriB\x06\n\x04_pidB\x06\n\x04_doiB\t\n\x07_pac_idB\x07\n\x05_fileB\x0c\n\n_thumbnailB\x0e\n\x0c_descriptionB\n\n\x08_remarksB\x0f\n\r_name_displayB\x10\n\x0e_search_vector\"V\n\x1b\x44\x61taRetrieveByNameNSRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12#\n\rnamespace_uri\x18\x02 \x01(\tR\x0cnamespaceUri\".\n\x13\x44\x61taRetrieveRequest\x12\x17\n\x07\x64\x61ta_id\x18\x01 \x01(\tR\x06\x64\x61taId\"\x13\n\x11\x44\x61taStreamRequest\"?\n\x18\x44\x61taSubsetDestroyRequest\x12#\n\rdatasubset_id\x18\x01 \x01(\tR\x0c\x64\x61tasubsetId\"\x17\n\x15\x44\x61taSubsetListRequest\"d\n\x16\x44\x61taSubsetListResponse\x12J\n\x07results\x18\x01 \x03(\x0b\x32\x30.lara_django.lara_django_data.DataSubsetResponseR\x07results\"\xee\x03\n\x1e\x44\x61taSubsetPartialUpdateRequest\x12(\n\rdatasubset_id\x18\x01 \x01(\tH\x00R\x0c\x64\x61tasubsetId\x88\x01\x01\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12\x19\n\x05group\x18\x04 \x01(\tH\x01R\x05group\x88\x01\x01\x12\x12\n\x04\x64\x61ta\x18\x05 \x03(\tR\x04\x64\x61ta\x12\x12\n\x04tags\x18\x06 \x03(\tR\x04tags\x12\x33\n\x16_partial_update_fields\x18\x07 \x03(\tR\x13PartialUpdateFields\x12\x12\n\x04name\x18\x08 \x01(\tR\x04name\x12%\n\x0b\x64\x65scription\x18\t \x01(\tH\x02R\x0b\x64\x65scription\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\n \x01(\tH\x03R\x14\x64\x61tetimeLastModified\x88\x01\x01\x12&\n\x0cname_display\x18\x0b \x01(\tH\x04R\x0bnameDisplay\x88\x01\x01\x12\x16\n\x06\x65ntity\x18\x0c \x01(\tR\x06\x65ntityB\x10\n\x0e_datasubset_idB\x08\n\x06_groupB\x0e\n\x0c_descriptionB\x19\n\x17_datetime_last_modifiedB\x0f\n\r_name_display\"\xac\x03\n\x11\x44\x61taSubsetRequest\x12(\n\rdatasubset_id\x18\x01 \x01(\tH\x00R\x0c\x64\x61tasubsetId\x88\x01\x01\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12\x19\n\x05group\x18\x04 \x01(\tH\x01R\x05group\x88\x01\x01\x12\x12\n\x04\x64\x61ta\x18\x05 \x03(\tR\x04\x64\x61ta\x12\x12\n\x04tags\x18\x06 \x03(\tR\x04tags\x12\x12\n\x04name\x18\x07 \x01(\tR\x04name\x12%\n\x0b\x64\x65scription\x18\x08 \x01(\tH\x02R\x0b\x64\x65scription\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\t \x01(\tH\x03R\x14\x64\x61tetimeLastModified\x88\x01\x01\x12&\n\x0cname_display\x18\n \x01(\tH\x04R\x0bnameDisplay\x88\x01\x01\x12\x16\n\x06\x65ntity\x18\x0b \x01(\tR\x06\x65ntityB\x10\n\x0e_datasubset_idB\x08\n\x06_groupB\x0e\n\x0c_descriptionB\x19\n\x17_datetime_last_modifiedB\x0f\n\r_name_display\"\xad\x03\n\x12\x44\x61taSubsetResponse\x12(\n\rdatasubset_id\x18\x01 \x01(\tH\x00R\x0c\x64\x61tasubsetId\x88\x01\x01\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12\x19\n\x05group\x18\x04 \x01(\tH\x01R\x05group\x88\x01\x01\x12\x12\n\x04\x64\x61ta\x18\x05 \x03(\tR\x04\x64\x61ta\x12\x12\n\x04tags\x18\x06 \x03(\tR\x04tags\x12\x12\n\x04name\x18\x07 \x01(\tR\x04name\x12%\n\x0b\x64\x65scription\x18\x08 \x01(\tH\x02R\x0b\x64\x65scription\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\t \x01(\tH\x03R\x14\x64\x61tetimeLastModified\x88\x01\x01\x12&\n\x0cname_display\x18\n \x01(\tH\x04R\x0bnameDisplay\x88\x01\x01\x12\x16\n\x06\x65ntity\x18\x0b \x01(\tR\x06\x65ntityB\x10\n\x0e_datasubset_idB\x08\n\x06_groupB\x0e\n\x0c_descriptionB\x19\n\x17_datetime_last_modifiedB\x0f\n\r_name_display\"@\n\x19\x44\x61taSubsetRetrieveRequest\x12#\n\rdatasubset_id\x18\x01 \x01(\tR\x0c\x64\x61tasubsetId\"\x19\n\x17\x44\x61taSubsetStreamRequest\"?\n\x18\x45valuationDestroyRequest\x12#\n\revaluation_id\x18\x01 \x01(\tR\x0c\x65valuationId\"\x17\n\x15\x45valuationListRequest\"d\n\x16\x45valuationListResponse\x12J\n\x07results\x18\x01 \x03(\x0b\x32\x30.lara_django.lara_django_data.EvaluationResponseR\x07results\"\xd0\t\n\x1e\x45valuationPartialUpdateRequest\x12(\n\revaluation_id\x18\x01 \x01(\tH\x00R\x0c\x65valuationId\x88\x01\x01\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12\x35\n\x14\x65val_method_instance\x18\x03 \x01(\tH\x01R\x12\x65valMethodInstance\x88\x01\x01\x12;\n\x17\x65val_procedure_instance\x18\x04 \x01(\tH\x02R\x15\x65valProcedureInstance\x88\x01\x01\x12!\n\x0cparent_evals\x18\x05 \x03(\tR\x0bparentEvals\x12\x1b\n\tdata_eval\x18\x06 \x03(\tR\x08\x64\x61taEval\x12!\n\x0c\x64\x61ta_results\x18\x07 \x03(\tR\x0b\x64\x61taResults\x12&\n\x0evisualisations\x18\x08 \x03(\tR\x0evisualisations\x12\x12\n\x04tags\x18\t \x03(\tR\x04tags\x12-\n\x12resources_external\x18\n \x03(\tR\x11resourcesExternal\x12\x33\n\x16_partial_update_fields\x18\x0b \x03(\tR\x13PartialUpdateFields\x12\x12\n\x04name\x18\x0c \x01(\tR\x04name\x12\x1d\n\x07version\x18\r \x01(\tH\x03R\x07version\x88\x01\x01\x12$\n\x0bhash_sha256\x18\x0e \x01(\tH\x04R\nhashSha256\x88\x01\x01\x12<\n\nparameters\x18\x0f \x01(\x0b\x32\x17.google.protobuf.StructH\x05R\nparameters\x88\x01\x01\x12\x15\n\x03iri\x18\x10 \x01(\tH\x06R\x03iri\x88\x01\x01\x12\x15\n\x03pid\x18\x11 \x01(\tH\x07R\x03pid\x88\x01\x01\x12\x15\n\x03\x64oi\x18\x12 \x01(\tH\x08R\x03\x64oi\x88\x01\x01\x12\x36\n\x07\x63\x61ption\x18\x13 \x01(\x0b\x32\x17.google.protobuf.StructH\tR\x07\x63\x61ption\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x14 \x01(\tH\nR\x0b\x64\x65scription\x88\x01\x01\x12.\n\x10\x64\x61tetime_created\x18\x15 \x01(\tH\x0bR\x0f\x64\x61tetimeCreated\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x16 \x01(\tH\x0cR\x14\x64\x61tetimeLastModified\x88\x01\x01\x12&\n\x0cname_display\x18\x17 \x01(\tH\rR\x0bnameDisplay\x88\x01\x01\x12(\n\rsearch_vector\x18\x18 \x01(\tH\x0eR\x0csearchVector\x88\x01\x01\x42\x10\n\x0e_evaluation_idB\x17\n\x15_eval_method_instanceB\x1a\n\x18_eval_procedure_instanceB\n\n\x08_versionB\x0e\n\x0c_hash_sha256B\r\n\x0b_parametersB\x06\n\x04_iriB\x06\n\x04_pidB\x06\n\x04_doiB\n\n\x08_captionB\x0e\n\x0c_descriptionB\x13\n\x11_datetime_createdB\x19\n\x17_datetime_last_modifiedB\x0f\n\r_name_displayB\x10\n\x0e_search_vector\"\x8e\t\n\x11\x45valuationRequest\x12(\n\revaluation_id\x18\x01 \x01(\tH\x00R\x0c\x65valuationId\x88\x01\x01\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12\x35\n\x14\x65val_method_instance\x18\x03 \x01(\tH\x01R\x12\x65valMethodInstance\x88\x01\x01\x12;\n\x17\x65val_procedure_instance\x18\x04 \x01(\tH\x02R\x15\x65valProcedureInstance\x88\x01\x01\x12!\n\x0cparent_evals\x18\x05 \x03(\tR\x0bparentEvals\x12\x1b\n\tdata_eval\x18\x06 \x03(\tR\x08\x64\x61taEval\x12!\n\x0c\x64\x61ta_results\x18\x07 \x03(\tR\x0b\x64\x61taResults\x12&\n\x0evisualisations\x18\x08 \x03(\tR\x0evisualisations\x12\x12\n\x04tags\x18\t \x03(\tR\x04tags\x12-\n\x12resources_external\x18\n \x03(\tR\x11resourcesExternal\x12\x12\n\x04name\x18\x0b \x01(\tR\x04name\x12\x1d\n\x07version\x18\x0c \x01(\tH\x03R\x07version\x88\x01\x01\x12$\n\x0bhash_sha256\x18\r \x01(\tH\x04R\nhashSha256\x88\x01\x01\x12<\n\nparameters\x18\x0e \x01(\x0b\x32\x17.google.protobuf.StructH\x05R\nparameters\x88\x01\x01\x12\x15\n\x03iri\x18\x0f \x01(\tH\x06R\x03iri\x88\x01\x01\x12\x15\n\x03pid\x18\x10 \x01(\tH\x07R\x03pid\x88\x01\x01\x12\x15\n\x03\x64oi\x18\x11 \x01(\tH\x08R\x03\x64oi\x88\x01\x01\x12\x36\n\x07\x63\x61ption\x18\x12 \x01(\x0b\x32\x17.google.protobuf.StructH\tR\x07\x63\x61ption\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x13 \x01(\tH\nR\x0b\x64\x65scription\x88\x01\x01\x12.\n\x10\x64\x61tetime_created\x18\x14 \x01(\tH\x0bR\x0f\x64\x61tetimeCreated\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x15 \x01(\tH\x0cR\x14\x64\x61tetimeLastModified\x88\x01\x01\x12&\n\x0cname_display\x18\x16 \x01(\tH\rR\x0bnameDisplay\x88\x01\x01\x12(\n\rsearch_vector\x18\x17 \x01(\tH\x0eR\x0csearchVector\x88\x01\x01\x42\x10\n\x0e_evaluation_idB\x17\n\x15_eval_method_instanceB\x1a\n\x18_eval_procedure_instanceB\n\n\x08_versionB\x0e\n\x0c_hash_sha256B\r\n\x0b_parametersB\x06\n\x04_iriB\x06\n\x04_pidB\x06\n\x04_doiB\n\n\x08_captionB\x0e\n\x0c_descriptionB\x13\n\x11_datetime_createdB\x19\n\x17_datetime_last_modifiedB\x0f\n\r_name_displayB\x10\n\x0e_search_vector\"\x8f\t\n\x12\x45valuationResponse\x12(\n\revaluation_id\x18\x01 \x01(\tH\x00R\x0c\x65valuationId\x88\x01\x01\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12\x35\n\x14\x65val_method_instance\x18\x03 \x01(\tH\x01R\x12\x65valMethodInstance\x88\x01\x01\x12;\n\x17\x65val_procedure_instance\x18\x04 \x01(\tH\x02R\x15\x65valProcedureInstance\x88\x01\x01\x12!\n\x0cparent_evals\x18\x05 \x03(\tR\x0bparentEvals\x12\x1b\n\tdata_eval\x18\x06 \x03(\tR\x08\x64\x61taEval\x12!\n\x0c\x64\x61ta_results\x18\x07 \x03(\tR\x0b\x64\x61taResults\x12&\n\x0evisualisations\x18\x08 \x03(\tR\x0evisualisations\x12\x12\n\x04tags\x18\t \x03(\tR\x04tags\x12-\n\x12resources_external\x18\n \x03(\tR\x11resourcesExternal\x12\x12\n\x04name\x18\x0b \x01(\tR\x04name\x12\x1d\n\x07version\x18\x0c \x01(\tH\x03R\x07version\x88\x01\x01\x12$\n\x0bhash_sha256\x18\r \x01(\tH\x04R\nhashSha256\x88\x01\x01\x12<\n\nparameters\x18\x0e \x01(\x0b\x32\x17.google.protobuf.StructH\x05R\nparameters\x88\x01\x01\x12\x15\n\x03iri\x18\x0f \x01(\tH\x06R\x03iri\x88\x01\x01\x12\x15\n\x03pid\x18\x10 \x01(\tH\x07R\x03pid\x88\x01\x01\x12\x15\n\x03\x64oi\x18\x11 \x01(\tH\x08R\x03\x64oi\x88\x01\x01\x12\x36\n\x07\x63\x61ption\x18\x12 \x01(\x0b\x32\x17.google.protobuf.StructH\tR\x07\x63\x61ption\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x13 \x01(\tH\nR\x0b\x64\x65scription\x88\x01\x01\x12.\n\x10\x64\x61tetime_created\x18\x14 \x01(\tH\x0bR\x0f\x64\x61tetimeCreated\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x15 \x01(\tH\x0cR\x14\x64\x61tetimeLastModified\x88\x01\x01\x12&\n\x0cname_display\x18\x16 \x01(\tH\rR\x0bnameDisplay\x88\x01\x01\x12(\n\rsearch_vector\x18\x17 \x01(\tH\x0eR\x0csearchVector\x88\x01\x01\x42\x10\n\x0e_evaluation_idB\x17\n\x15_eval_method_instanceB\x1a\n\x18_eval_procedure_instanceB\n\n\x08_versionB\x0e\n\x0c_hash_sha256B\r\n\x0b_parametersB\x06\n\x04_iriB\x06\n\x04_pidB\x06\n\x04_doiB\n\n\x08_captionB\x0e\n\x0c_descriptionB\x13\n\x11_datetime_createdB\x19\n\x17_datetime_last_modifiedB\x0f\n\r_name_displayB\x10\n\x0e_search_vector\"\\\n!EvaluationRetrieveByNameNSRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12#\n\rnamespace_uri\x18\x02 \x01(\tR\x0cnamespaceUri\"@\n\x19\x45valuationRetrieveRequest\x12#\n\revaluation_id\x18\x01 \x01(\tR\x0c\x65valuationId\"\x19\n\x17\x45valuationStreamRequest\"<\n\x17\x45xtraDataDestroyRequest\x12!\n\x0c\x65xtradata_id\x18\x01 \x01(\tR\x0b\x65xtradataId\"\x16\n\x14\x45xtraDataListRequest\"b\n\x15\x45xtraDataListResponse\x12I\n\x07results\x18\x01 \x03(\x0b\x32/.lara_django.lara_django_data.ExtraDataResponseR\x07results\"\xb7\x07\n\x1d\x45xtraDataPartialUpdateRequest\x12&\n\x0c\x65xtradata_id\x18\x01 \x01(\tH\x00R\x0b\x65xtradataId\x88\x01\x01\x12 \n\tdata_type\x18\x02 \x01(\tH\x01R\x08\x64\x61taType\x88\x01\x01\x12\x1c\n\tnamespace\x18\x03 \x01(\tR\tnamespace\x12\"\n\nmedia_type\x18\x04 \x01(\tH\x02R\tmediaType\x88\x01\x01\x12\x33\n\x16_partial_update_fields\x18\x05 \x03(\tR\x13PartialUpdateFields\x12\x12\n\x04name\x18\x07 \x01(\tR\x04name\x12 \n\tname_full\x18\x08 \x01(\tH\x03R\x08nameFull\x88\x01\x01\x12\x18\n\x07version\x18\t \x01(\tR\x07version\x12$\n\x0bhash_sha256\x18\n \x01(\tH\x04R\nhashSha256\x88\x01\x01\x12\x39\n\tdata_json\x18\x0b \x01(\x0b\x32\x17.google.protobuf.StructH\x05R\x08\x64\x61taJson\x88\x01\x01\x12\x15\n\x03iri\x18\x0c \x01(\tH\x06R\x03iri\x88\x01\x01\x12\x15\n\x03url\x18\r \x01(\tH\x07R\x03url\x88\x01\x01\x12.\n\x10\x64\x61tetime_created\x18\x0e \x01(\tH\x08R\x0f\x64\x61tetimeCreated\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x0f \x01(\tH\tR\x14\x64\x61tetimeLastModified\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x10 \x01(\tH\nR\x0b\x64\x65scription\x88\x01\x01\x12\x17\n\x04\x66ile\x18\x11 \x01(\tH\x0bR\x04\x66ile\x88\x01\x01\x12\x19\n\x05image\x18\x12 \x01(\tH\x0cR\x05image\x88\x01\x01\x12&\n\x0cname_display\x18\x13 \x01(\tH\rR\x0bnameDisplay\x88\x01\x01\x12(\n\rsearch_vector\x18\x14 \x01(\tH\x0eR\x0csearchVector\x88\x01\x01\x42\x0f\n\r_extradata_idB\x0c\n\n_data_typeB\r\n\x0b_media_typeB\x0c\n\n_name_fullB\x0e\n\x0c_hash_sha256B\x0c\n\n_data_jsonB\x06\n\x04_iriB\x06\n\x04_urlB\x13\n\x11_datetime_createdB\x19\n\x17_datetime_last_modifiedB\x0e\n\x0c_descriptionB\x07\n\x05_fileB\x08\n\x06_imageB\x0f\n\r_name_displayB\x10\n\x0e_search_vector\"\xf5\x06\n\x10\x45xtraDataRequest\x12&\n\x0c\x65xtradata_id\x18\x01 \x01(\tH\x00R\x0b\x65xtradataId\x88\x01\x01\x12 \n\tdata_type\x18\x02 \x01(\tH\x01R\x08\x64\x61taType\x88\x01\x01\x12\x1c\n\tnamespace\x18\x03 \x01(\tR\tnamespace\x12\"\n\nmedia_type\x18\x04 \x01(\tH\x02R\tmediaType\x88\x01\x01\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12 \n\tname_full\x18\x07 \x01(\tH\x03R\x08nameFull\x88\x01\x01\x12\x18\n\x07version\x18\x08 \x01(\tR\x07version\x12$\n\x0bhash_sha256\x18\t \x01(\tH\x04R\nhashSha256\x88\x01\x01\x12\x39\n\tdata_json\x18\n \x01(\x0b\x32\x17.google.protobuf.StructH\x05R\x08\x64\x61taJson\x88\x01\x01\x12\x15\n\x03iri\x18\x0b \x01(\tH\x06R\x03iri\x88\x01\x01\x12\x15\n\x03url\x18\x0c \x01(\tH\x07R\x03url\x88\x01\x01\x12.\n\x10\x64\x61tetime_created\x18\r \x01(\tH\x08R\x0f\x64\x61tetimeCreated\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x0e \x01(\tH\tR\x14\x64\x61tetimeLastModified\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x0f \x01(\tH\nR\x0b\x64\x65scription\x88\x01\x01\x12\x17\n\x04\x66ile\x18\x10 \x01(\tH\x0bR\x04\x66ile\x88\x01\x01\x12\x19\n\x05image\x18\x11 \x01(\tH\x0cR\x05image\x88\x01\x01\x12&\n\x0cname_display\x18\x12 \x01(\tH\rR\x0bnameDisplay\x88\x01\x01\x12(\n\rsearch_vector\x18\x13 \x01(\tH\x0eR\x0csearchVector\x88\x01\x01\x42\x0f\n\r_extradata_idB\x0c\n\n_data_typeB\r\n\x0b_media_typeB\x0c\n\n_name_fullB\x0e\n\x0c_hash_sha256B\x0c\n\n_data_jsonB\x06\n\x04_iriB\x06\n\x04_urlB\x13\n\x11_datetime_createdB\x19\n\x17_datetime_last_modifiedB\x0e\n\x0c_descriptionB\x07\n\x05_fileB\x08\n\x06_imageB\x0f\n\r_name_displayB\x10\n\x0e_search_vector\"\xf6\x06\n\x11\x45xtraDataResponse\x12&\n\x0c\x65xtradata_id\x18\x01 \x01(\tH\x00R\x0b\x65xtradataId\x88\x01\x01\x12 \n\tdata_type\x18\x02 \x01(\tH\x01R\x08\x64\x61taType\x88\x01\x01\x12\x1c\n\tnamespace\x18\x03 \x01(\tR\tnamespace\x12\"\n\nmedia_type\x18\x04 \x01(\tH\x02R\tmediaType\x88\x01\x01\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12 \n\tname_full\x18\x07 \x01(\tH\x03R\x08nameFull\x88\x01\x01\x12\x18\n\x07version\x18\x08 \x01(\tR\x07version\x12$\n\x0bhash_sha256\x18\t \x01(\tH\x04R\nhashSha256\x88\x01\x01\x12\x39\n\tdata_json\x18\n \x01(\x0b\x32\x17.google.protobuf.StructH\x05R\x08\x64\x61taJson\x88\x01\x01\x12\x15\n\x03iri\x18\x0b \x01(\tH\x06R\x03iri\x88\x01\x01\x12\x15\n\x03url\x18\x0c \x01(\tH\x07R\x03url\x88\x01\x01\x12.\n\x10\x64\x61tetime_created\x18\r \x01(\tH\x08R\x0f\x64\x61tetimeCreated\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x0e \x01(\tH\tR\x14\x64\x61tetimeLastModified\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x0f \x01(\tH\nR\x0b\x64\x65scription\x88\x01\x01\x12\x17\n\x04\x66ile\x18\x10 \x01(\tH\x0bR\x04\x66ile\x88\x01\x01\x12\x19\n\x05image\x18\x11 \x01(\tH\x0cR\x05image\x88\x01\x01\x12&\n\x0cname_display\x18\x12 \x01(\tH\rR\x0bnameDisplay\x88\x01\x01\x12(\n\rsearch_vector\x18\x13 \x01(\tH\x0eR\x0csearchVector\x88\x01\x01\x42\x0f\n\r_extradata_idB\x0c\n\n_data_typeB\r\n\x0b_media_typeB\x0c\n\n_name_fullB\x0e\n\x0c_hash_sha256B\x0c\n\n_data_jsonB\x06\n\x04_iriB\x06\n\x04_urlB\x13\n\x11_datetime_createdB\x19\n\x17_datetime_last_modifiedB\x0e\n\x0c_descriptionB\x07\n\x05_fileB\x08\n\x06_imageB\x0f\n\r_name_displayB\x10\n\x0e_search_vector\"=\n\x18\x45xtraDataRetrieveRequest\x12!\n\x0c\x65xtradata_id\x18\x01 \x01(\tR\x0b\x65xtradataId\"\x18\n\x16\x45xtraDataStreamRequest\"]\n\x11\x46ileDownloadChunk\x12\x1a\n\x08\x66ilename\x18\x01 \x01(\tR\x08\x66ilename\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\x0cR\x04\x64\x61ta\x12\x18\n\x07success\x18\x03 \x01(\x08R\x07success\"J\n\x10\x46ileDownloadInfo\x12\x17\n\x07item_id\x18\x01 \x01(\tR\x06itemId\x12\x1d\n\nchunk_size\x18\x02 \x01(\x04R\tchunkSize\"g\n\x0f\x46ileUploadChunk\x12\x1a\n\x08\x66ilename\x18\x01 \x01(\tR\x08\x66ilename\x12$\n\x0eupdate_item_id\x18\x02 \x01(\tR\x0cupdateItemId\x12\x12\n\x04\x64\x61ta\x18\x03 \x01(\x0cR\x04\x64\x61ta\"*\n\x0e\x46ileUploadInfo\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\"i\n\x12ImageDownloadChunk\x12%\n\x0e\x66ilename_image\x18\x01 \x01(\tR\rfilenameImage\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\x0cR\x04\x64\x61ta\x12\x18\n\x07success\x18\x03 \x01(\x08R\x07success\"K\n\x11ImageDownloadInfo\x12\x17\n\x07item_id\x18\x01 \x01(\tR\x06itemId\x12\x1d\n\nchunk_size\x18\x02 \x01(\x04R\tchunkSize\"h\n\x10ImageUploadChunk\x12\x1a\n\x08\x66ilename\x18\x01 \x01(\tR\x08\x66ilename\x12$\n\x0eupdate_item_id\x18\x02 \x01(\tR\x0cupdateItemId\x12\x12\n\x04\x64\x61ta\x18\x03 \x01(\x0cR\x04\x64\x61ta\"+\n\x0fImageUploadInfo\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\"H\n\x1bVisualisationDestroyRequest\x12)\n\x10visualisation_id\x18\x01 \x01(\tR\x0fvisualisationId\"\x1a\n\x18VisualisationListRequest\"j\n\x19VisualisationListResponse\x12M\n\x07results\x18\x01 \x03(\x0b\x32\x33.lara_django.lara_django_data.VisualisationResponseR\x07results\"\xbd\t\n!VisualisationPartialUpdateRequest\x12.\n\x10visualisation_id\x18\x01 \x01(\tH\x00R\x0fvisualisationId\x88\x01\x01\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12 \n\tdata_type\x18\x03 \x01(\tH\x01R\x08\x64\x61taType\x88\x01\x01\x12=\n\x18plotting_method_instance\x18\x04 \x01(\tH\x02R\x16plottingMethodInstance\x88\x01\x01\x12\x43\n\x1bplotting_procedure_instance\x18\x05 \x01(\tH\x03R\x19plottingProcedureInstance\x88\x01\x01\x12\x12\n\x04tags\x18\x06 \x03(\tR\x04tags\x12-\n\x12resources_external\x18\x07 \x03(\tR\x11resourcesExternal\x12\x33\n\x16_partial_update_fields\x18\x08 \x03(\tR\x13PartialUpdateFields\x12\x12\n\x04name\x18\t \x01(\tR\x04name\x12\x1d\n\x07version\x18\n \x01(\tH\x04R\x07version\x88\x01\x01\x12O\n\x14rendering_components\x18\x0b \x01(\x0b\x32\x17.google.protobuf.StructH\x05R\x13renderingComponents\x88\x01\x01\x12\x15\n\x03iri\x18\x0c \x01(\tH\x06R\x03iri\x88\x01\x01\x12\x36\n\x07\x63\x61ption\x18\r \x01(\x0b\x32\x17.google.protobuf.StructH\x07R\x07\x63\x61ption\x88\x01\x01\x12!\n\tthumbnail\x18\x0e \x01(\tH\x08R\tthumbnail\x88\x01\x01\x12\x19\n\x05image\x18\x0f \x01(\tH\tR\x05image\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x10 \x01(\tH\nR\x0b\x64\x65scription\x88\x01\x01\x12.\n\x10\x64\x61tetime_created\x18\x11 \x01(\tH\x0bR\x0f\x64\x61tetimeCreated\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x12 \x01(\tH\x0cR\x14\x64\x61tetimeLastModified\x88\x01\x01\x12&\n\x0cname_display\x18\x13 \x01(\tH\rR\x0bnameDisplay\x88\x01\x01\x12\x19\n\x05order\x18\x14 \x01(\x05H\x0eR\x05order\x88\x01\x01\x12(\n\rsearch_vector\x18\x15 \x01(\tH\x0fR\x0csearchVector\x88\x01\x01\x42\x13\n\x11_visualisation_idB\x0c\n\n_data_typeB\x1b\n\x19_plotting_method_instanceB\x1e\n\x1c_plotting_procedure_instanceB\n\n\x08_versionB\x17\n\x15_rendering_componentsB\x06\n\x04_iriB\n\n\x08_captionB\x0c\n\n_thumbnailB\x08\n\x06_imageB\x0e\n\x0c_descriptionB\x13\n\x11_datetime_createdB\x19\n\x17_datetime_last_modifiedB\x0f\n\r_name_displayB\x08\n\x06_orderB\x10\n\x0e_search_vector\"\xfb\x08\n\x14VisualisationRequest\x12.\n\x10visualisation_id\x18\x01 \x01(\tH\x00R\x0fvisualisationId\x88\x01\x01\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12 \n\tdata_type\x18\x03 \x01(\tH\x01R\x08\x64\x61taType\x88\x01\x01\x12=\n\x18plotting_method_instance\x18\x04 \x01(\tH\x02R\x16plottingMethodInstance\x88\x01\x01\x12\x43\n\x1bplotting_procedure_instance\x18\x05 \x01(\tH\x03R\x19plottingProcedureInstance\x88\x01\x01\x12\x12\n\x04tags\x18\x06 \x03(\tR\x04tags\x12-\n\x12resources_external\x18\x07 \x03(\tR\x11resourcesExternal\x12\x12\n\x04name\x18\x08 \x01(\tR\x04name\x12\x1d\n\x07version\x18\t \x01(\tH\x04R\x07version\x88\x01\x01\x12O\n\x14rendering_components\x18\n \x01(\x0b\x32\x17.google.protobuf.StructH\x05R\x13renderingComponents\x88\x01\x01\x12\x15\n\x03iri\x18\x0b \x01(\tH\x06R\x03iri\x88\x01\x01\x12\x36\n\x07\x63\x61ption\x18\x0c \x01(\x0b\x32\x17.google.protobuf.StructH\x07R\x07\x63\x61ption\x88\x01\x01\x12!\n\tthumbnail\x18\r \x01(\tH\x08R\tthumbnail\x88\x01\x01\x12\x19\n\x05image\x18\x0e \x01(\tH\tR\x05image\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x0f \x01(\tH\nR\x0b\x64\x65scription\x88\x01\x01\x12.\n\x10\x64\x61tetime_created\x18\x10 \x01(\tH\x0bR\x0f\x64\x61tetimeCreated\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x11 \x01(\tH\x0cR\x14\x64\x61tetimeLastModified\x88\x01\x01\x12&\n\x0cname_display\x18\x12 \x01(\tH\rR\x0bnameDisplay\x88\x01\x01\x12\x19\n\x05order\x18\x13 \x01(\x05H\x0eR\x05order\x88\x01\x01\x12(\n\rsearch_vector\x18\x14 \x01(\tH\x0fR\x0csearchVector\x88\x01\x01\x42\x13\n\x11_visualisation_idB\x0c\n\n_data_typeB\x1b\n\x19_plotting_method_instanceB\x1e\n\x1c_plotting_procedure_instanceB\n\n\x08_versionB\x17\n\x15_rendering_componentsB\x06\n\x04_iriB\n\n\x08_captionB\x0c\n\n_thumbnailB\x08\n\x06_imageB\x0e\n\x0c_descriptionB\x13\n\x11_datetime_createdB\x19\n\x17_datetime_last_modifiedB\x0f\n\r_name_displayB\x08\n\x06_orderB\x10\n\x0e_search_vector\"\xfc\x08\n\x15VisualisationResponse\x12.\n\x10visualisation_id\x18\x01 \x01(\tH\x00R\x0fvisualisationId\x88\x01\x01\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12 \n\tdata_type\x18\x03 \x01(\tH\x01R\x08\x64\x61taType\x88\x01\x01\x12=\n\x18plotting_method_instance\x18\x04 \x01(\tH\x02R\x16plottingMethodInstance\x88\x01\x01\x12\x43\n\x1bplotting_procedure_instance\x18\x05 \x01(\tH\x03R\x19plottingProcedureInstance\x88\x01\x01\x12\x12\n\x04tags\x18\x06 \x03(\tR\x04tags\x12-\n\x12resources_external\x18\x07 \x03(\tR\x11resourcesExternal\x12\x12\n\x04name\x18\x08 \x01(\tR\x04name\x12\x1d\n\x07version\x18\t \x01(\tH\x04R\x07version\x88\x01\x01\x12O\n\x14rendering_components\x18\n \x01(\x0b\x32\x17.google.protobuf.StructH\x05R\x13renderingComponents\x88\x01\x01\x12\x15\n\x03iri\x18\x0b \x01(\tH\x06R\x03iri\x88\x01\x01\x12\x36\n\x07\x63\x61ption\x18\x0c \x01(\x0b\x32\x17.google.protobuf.StructH\x07R\x07\x63\x61ption\x88\x01\x01\x12!\n\tthumbnail\x18\r \x01(\tH\x08R\tthumbnail\x88\x01\x01\x12\x19\n\x05image\x18\x0e \x01(\tH\tR\x05image\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x0f \x01(\tH\nR\x0b\x64\x65scription\x88\x01\x01\x12.\n\x10\x64\x61tetime_created\x18\x10 \x01(\tH\x0bR\x0f\x64\x61tetimeCreated\x88\x01\x01\x12\x39\n\x16\x64\x61tetime_last_modified\x18\x11 \x01(\tH\x0cR\x14\x64\x61tetimeLastModified\x88\x01\x01\x12&\n\x0cname_display\x18\x12 \x01(\tH\rR\x0bnameDisplay\x88\x01\x01\x12\x19\n\x05order\x18\x13 \x01(\x05H\x0eR\x05order\x88\x01\x01\x12(\n\rsearch_vector\x18\x14 \x01(\tH\x0fR\x0csearchVector\x88\x01\x01\x42\x13\n\x11_visualisation_idB\x0c\n\n_data_typeB\x1b\n\x19_plotting_method_instanceB\x1e\n\x1c_plotting_procedure_instanceB\n\n\x08_versionB\x17\n\x15_rendering_componentsB\x06\n\x04_iriB\n\n\x08_captionB\x0c\n\n_thumbnailB\x08\n\x06_imageB\x0e\n\x0c_descriptionB\x13\n\x11_datetime_createdB\x19\n\x17_datetime_last_modifiedB\x0f\n\r_name_displayB\x08\n\x06_orderB\x10\n\x0e_search_vector\"_\n$VisualisationRetrieveByNameNSRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12#\n\rnamespace_uri\x18\x02 \x01(\tR\x0cnamespaceUri\"I\n\x1cVisualisationRetrieveRequest\x12)\n\x10visualisation_id\x18\x01 \x01(\tR\x0fvisualisationId2\xb8\n\n\x0e\x44\x61taController\x12\x61\n\x06\x43reate\x12).lara_django.lara_django_data.DataRequest\x1a*.lara_django.lara_django_data.DataResponse\"\x00\x12U\n\x07\x44\x65stroy\x12\x30.lara_django.lara_django_data.DataDestroyRequest\x1a\x16.google.protobuf.Empty\"\x00\x12s\n\x0c\x44ownloadFile\x12..lara_django.lara_django_data.FileDownloadInfo\x1a/.lara_django.lara_django_data.FileDownloadChunk\"\x00\x30\x01\x12v\n\rDownloadImage\x12/.lara_django.lara_django_data.ImageDownloadInfo\x1a\x30.lara_django.lara_django_data.ImageDownloadChunk\"\x00\x30\x01\x12g\n\x04List\x12-.lara_django.lara_django_data.DataListRequest\x1a..lara_django.lara_django_data.DataListResponse\"\x00\x12u\n\rPartialUpdate\x12\x36.lara_django.lara_django_data.DataPartialUpdateRequest\x1a*.lara_django.lara_django_data.DataResponse\"\x00\x12k\n\x08Retrieve\x12\x31.lara_django.lara_django_data.DataRetrieveRequest\x1a*.lara_django.lara_django_data.DataResponse\"\x00\x12\x82\x01\n\x17RetrieveByNameNamespace\x12\x39.lara_django.lara_django_data.DataRetrieveByNameNSRequest\x1a*.lara_django.lara_django_data.DataResponse\"\x00\x12i\n\x06Stream\x12/.lara_django.lara_django_data.DataStreamRequest\x1a*.lara_django.lara_django_data.DataResponse\"\x00\x30\x01\x12\x61\n\x06Update\x12).lara_django.lara_django_data.DataRequest\x1a*.lara_django.lara_django_data.DataResponse\"\x00\x12m\n\nUploadFile\x12-.lara_django.lara_django_data.FileUploadChunk\x1a,.lara_django.lara_django_data.FileUploadInfo\"\x00(\x01\x12p\n\x0bUploadImage\x12..lara_django.lara_django_data.ImageUploadChunk\x1a-.lara_django.lara_django_data.ImageUploadInfo\"\x00(\x01\x32\xba\x06\n\x14\x44\x61taSubsetController\x12m\n\x06\x43reate\x12/.lara_django.lara_django_data.DataSubsetRequest\x1a\x30.lara_django.lara_django_data.DataSubsetResponse\"\x00\x12[\n\x07\x44\x65stroy\x12\x36.lara_django.lara_django_data.DataSubsetDestroyRequest\x1a\x16.google.protobuf.Empty\"\x00\x12s\n\x04List\x12\x33.lara_django.lara_django_data.DataSubsetListRequest\x1a\x34.lara_django.lara_django_data.DataSubsetListResponse\"\x00\x12\x81\x01\n\rPartialUpdate\x12<.lara_django.lara_django_data.DataSubsetPartialUpdateRequest\x1a\x30.lara_django.lara_django_data.DataSubsetResponse\"\x00\x12w\n\x08Retrieve\x12\x37.lara_django.lara_django_data.DataSubsetRetrieveRequest\x1a\x30.lara_django.lara_django_data.DataSubsetResponse\"\x00\x12u\n\x06Stream\x12\x35.lara_django.lara_django_data.DataSubsetStreamRequest\x1a\x30.lara_django.lara_django_data.DataSubsetResponse\"\x00\x30\x01\x12m\n\x06Update\x12/.lara_django.lara_django_data.DataSubsetRequest\x1a\x30.lara_django.lara_django_data.DataSubsetResponse\"\x00\x32\x99\x0b\n\x14\x45valuationController\x12m\n\x06\x43reate\x12/.lara_django.lara_django_data.EvaluationRequest\x1a\x30.lara_django.lara_django_data.EvaluationResponse\"\x00\x12[\n\x07\x44\x65stroy\x12\x36.lara_django.lara_django_data.EvaluationDestroyRequest\x1a\x16.google.protobuf.Empty\"\x00\x12s\n\x0c\x44ownloadFile\x12..lara_django.lara_django_data.FileDownloadInfo\x1a/.lara_django.lara_django_data.FileDownloadChunk\"\x00\x30\x01\x12v\n\rDownloadImage\x12/.lara_django.lara_django_data.ImageDownloadInfo\x1a\x30.lara_django.lara_django_data.ImageDownloadChunk\"\x00\x30\x01\x12s\n\x04List\x12\x33.lara_django.lara_django_data.EvaluationListRequest\x1a\x34.lara_django.lara_django_data.EvaluationListResponse\"\x00\x12\x81\x01\n\rPartialUpdate\x12<.lara_django.lara_django_data.EvaluationPartialUpdateRequest\x1a\x30.lara_django.lara_django_data.EvaluationResponse\"\x00\x12w\n\x08Retrieve\x12\x37.lara_django.lara_django_data.EvaluationRetrieveRequest\x1a\x30.lara_django.lara_django_data.EvaluationResponse\"\x00\x12\x8e\x01\n\x17RetrieveByNameNamespace\x12?.lara_django.lara_django_data.EvaluationRetrieveByNameNSRequest\x1a\x30.lara_django.lara_django_data.EvaluationResponse\"\x00\x12u\n\x06Stream\x12\x35.lara_django.lara_django_data.EvaluationStreamRequest\x1a\x30.lara_django.lara_django_data.EvaluationResponse\"\x00\x30\x01\x12m\n\x06Update\x12/.lara_django.lara_django_data.EvaluationRequest\x1a\x30.lara_django.lara_django_data.EvaluationResponse\"\x00\x12m\n\nUploadFile\x12-.lara_django.lara_django_data.FileUploadChunk\x1a,.lara_django.lara_django_data.FileUploadInfo\"\x00(\x01\x12p\n\x0bUploadImage\x12..lara_django.lara_django_data.ImageUploadChunk\x1a-.lara_django.lara_django_data.ImageUploadInfo\"\x00(\x01\x32\xab\x06\n\x13\x45xtraDataController\x12k\n\x06\x43reate\x12..lara_django.lara_django_data.ExtraDataRequest\x1a/.lara_django.lara_django_data.ExtraDataResponse\"\x00\x12Z\n\x07\x44\x65stroy\x12\x35.lara_django.lara_django_data.ExtraDataDestroyRequest\x1a\x16.google.protobuf.Empty\"\x00\x12q\n\x04List\x12\x32.lara_django.lara_django_data.ExtraDataListRequest\x1a\x33.lara_django.lara_django_data.ExtraDataListResponse\"\x00\x12\x7f\n\rPartialUpdate\x12;.lara_django.lara_django_data.ExtraDataPartialUpdateRequest\x1a/.lara_django.lara_django_data.ExtraDataResponse\"\x00\x12u\n\x08Retrieve\x12\x36.lara_django.lara_django_data.ExtraDataRetrieveRequest\x1a/.lara_django.lara_django_data.ExtraDataResponse\"\x00\x12s\n\x06Stream\x12\x34.lara_django.lara_django_data.ExtraDataStreamRequest\x1a/.lara_django.lara_django_data.ExtraDataResponse\"\x00\x30\x01\x12k\n\x06Update\x12..lara_django.lara_django_data.ExtraDataRequest\x1a/.lara_django.lara_django_data.ExtraDataResponse\"\x00\x32\xcc\n\n\x17VisualisationController\x12s\n\x06\x43reate\x12\x32.lara_django.lara_django_data.VisualisationRequest\x1a\x33.lara_django.lara_django_data.VisualisationResponse\"\x00\x12^\n\x07\x44\x65stroy\x12\x39.lara_django.lara_django_data.VisualisationDestroyRequest\x1a\x16.google.protobuf.Empty\"\x00\x12s\n\x0c\x44ownloadFile\x12..lara_django.lara_django_data.FileDownloadInfo\x1a/.lara_django.lara_django_data.FileDownloadChunk\"\x00\x30\x01\x12v\n\rDownloadImage\x12/.lara_django.lara_django_data.ImageDownloadInfo\x1a\x30.lara_django.lara_django_data.ImageDownloadChunk\"\x00\x30\x01\x12y\n\x04List\x12\x36.lara_django.lara_django_data.VisualisationListRequest\x1a\x37.lara_django.lara_django_data.VisualisationListResponse\"\x00\x12\x87\x01\n\rPartialUpdate\x12?.lara_django.lara_django_data.VisualisationPartialUpdateRequest\x1a\x33.lara_django.lara_django_data.VisualisationResponse\"\x00\x12}\n\x08Retrieve\x12:.lara_django.lara_django_data.VisualisationRetrieveRequest\x1a\x33.lara_django.lara_django_data.VisualisationResponse\"\x00\x12\x94\x01\n\x17RetrieveByNameNamespace\x12\x42.lara_django.lara_django_data.VisualisationRetrieveByNameNSRequest\x1a\x33.lara_django.lara_django_data.VisualisationResponse\"\x00\x12s\n\x06Update\x12\x32.lara_django.lara_django_data.VisualisationRequest\x1a\x33.lara_django.lara_django_data.VisualisationResponse\"\x00\x12m\n\nUploadFile\x12-.lara_django.lara_django_data.FileUploadChunk\x1a,.lara_django.lara_django_data.FileUploadInfo\"\x00(\x01\x12p\n\x0bUploadImage\x12..lara_django.lara_django_data.ImageUploadChunk\x1a-.lara_django.lara_django_data.ImageUploadInfo\"\x00(\x01\x42\x81\x02\n com.lara_django.lara_django_dataB\x13LaraDjangoDataProtoP\x01ZCgitlab.com/larasuite/lara-django-data/grpc/lara_django_data_grpc/v1\xa2\x02\x03LLX\xaa\x02\x19LaraDjango.LaraDjangoData\xca\x02\x19LaraDjango\\LaraDjangoData\xe2\x02%LaraDjango\\LaraDjangoData\\GPBMetadata\xea\x02\x1aLaraDjango::LaraDjangoDatab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'lara_django_data_grpc.v1.lara_django_data_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n com.lara_django.lara_django_dataB\023LaraDjangoDataProtoP\001ZCgitlab.com/larasuite/lara-django-data/grpc/lara_django_data_grpc/v1\242\002\003LLX\252\002\031LaraDjango.LaraDjangoData\312\002\031LaraDjango\\LaraDjangoData\342\002%LaraDjango\\LaraDjangoData\\GPBMetadata\352\002\032LaraDjango::LaraDjangoData'
  _globals['_DATADESTROYREQUEST']._serialized_start=140
  _globals['_DATADESTROYREQUEST']._serialized_end=185
  _globals['_DATALISTREQUEST']._serialized_start=187
  _globals['_DATALISTREQUEST']._serialized_end=204
  _globals['_DATALISTRESPONSE']._serialized_start=206
  _globals['_DATALISTRESPONSE']._serialized_end=294
  _globals['_DATAPARTIALUPDATEREQUEST']._serialized_start=297
  _globals['_DATAPARTIALUPDATEREQUEST']._serialized_end=2042
  _globals['_DATAREQUEST']._serialized_start=2045
  _globals['_DATAREQUEST']._serialized_end=3724
  _globals['_DATARESPONSE']._serialized_start=3727
  _globals['_DATARESPONSE']._serialized_end=5407
  _globals['_DATARETRIEVEBYNAMENSREQUEST']._serialized_start=5409
  _globals['_DATARETRIEVEBYNAMENSREQUEST']._serialized_end=5495
  _globals['_DATARETRIEVEREQUEST']._serialized_start=5497
  _globals['_DATARETRIEVEREQUEST']._serialized_end=5543
  _globals['_DATASTREAMREQUEST']._serialized_start=5545
  _globals['_DATASTREAMREQUEST']._serialized_end=5564
  _globals['_DATASUBSETDESTROYREQUEST']._serialized_start=5566
  _globals['_DATASUBSETDESTROYREQUEST']._serialized_end=5629
  _globals['_DATASUBSETLISTREQUEST']._serialized_start=5631
  _globals['_DATASUBSETLISTREQUEST']._serialized_end=5654
  _globals['_DATASUBSETLISTRESPONSE']._serialized_start=5656
  _globals['_DATASUBSETLISTRESPONSE']._serialized_end=5756
  _globals['_DATASUBSETPARTIALUPDATEREQUEST']._serialized_start=5759
  _globals['_DATASUBSETPARTIALUPDATEREQUEST']._serialized_end=6253
  _globals['_DATASUBSETREQUEST']._serialized_start=6256
  _globals['_DATASUBSETREQUEST']._serialized_end=6684
  _globals['_DATASUBSETRESPONSE']._serialized_start=6687
  _globals['_DATASUBSETRESPONSE']._serialized_end=7116
  _globals['_DATASUBSETRETRIEVEREQUEST']._serialized_start=7118
  _globals['_DATASUBSETRETRIEVEREQUEST']._serialized_end=7182
  _globals['_DATASUBSETSTREAMREQUEST']._serialized_start=7184
  _globals['_DATASUBSETSTREAMREQUEST']._serialized_end=7209
  _globals['_EVALUATIONDESTROYREQUEST']._serialized_start=7211
  _globals['_EVALUATIONDESTROYREQUEST']._serialized_end=7274
  _globals['_EVALUATIONLISTREQUEST']._serialized_start=7276
  _globals['_EVALUATIONLISTREQUEST']._serialized_end=7299
  _globals['_EVALUATIONLISTRESPONSE']._serialized_start=7301
  _globals['_EVALUATIONLISTRESPONSE']._serialized_end=7401
  _globals['_EVALUATIONPARTIALUPDATEREQUEST']._serialized_start=7404
  _globals['_EVALUATIONPARTIALUPDATEREQUEST']._serialized_end=8636
  _globals['_EVALUATIONREQUEST']._serialized_start=8639
  _globals['_EVALUATIONREQUEST']._serialized_end=9805
  _globals['_EVALUATIONRESPONSE']._serialized_start=9808
  _globals['_EVALUATIONRESPONSE']._serialized_end=10975
  _globals['_EVALUATIONRETRIEVEBYNAMENSREQUEST']._serialized_start=10977
  _globals['_EVALUATIONRETRIEVEBYNAMENSREQUEST']._serialized_end=11069
  _globals['_EVALUATIONRETRIEVEREQUEST']._serialized_start=11071
  _globals['_EVALUATIONRETRIEVEREQUEST']._serialized_end=11135
  _globals['_EVALUATIONSTREAMREQUEST']._serialized_start=11137
  _globals['_EVALUATIONSTREAMREQUEST']._serialized_end=11162
  _globals['_EXTRADATADESTROYREQUEST']._serialized_start=11164
  _globals['_EXTRADATADESTROYREQUEST']._serialized_end=11224
  _globals['_EXTRADATALISTREQUEST']._serialized_start=11226
  _globals['_EXTRADATALISTREQUEST']._serialized_end=11248
  _globals['_EXTRADATALISTRESPONSE']._serialized_start=11250
  _globals['_EXTRADATALISTRESPONSE']._serialized_end=11348
  _globals['_EXTRADATAPARTIALUPDATEREQUEST']._serialized_start=11351
  _globals['_EXTRADATAPARTIALUPDATEREQUEST']._serialized_end=12302
  _globals['_EXTRADATAREQUEST']._serialized_start=12305
  _globals['_EXTRADATAREQUEST']._serialized_end=13190
  _globals['_EXTRADATARESPONSE']._serialized_start=13193
  _globals['_EXTRADATARESPONSE']._serialized_end=14079
  _globals['_EXTRADATARETRIEVEREQUEST']._serialized_start=14081
  _globals['_EXTRADATARETRIEVEREQUEST']._serialized_end=14142
  _globals['_EXTRADATASTREAMREQUEST']._serialized_start=14144
  _globals['_EXTRADATASTREAMREQUEST']._serialized_end=14168
  _globals['_FILEDOWNLOADCHUNK']._serialized_start=14170
  _globals['_FILEDOWNLOADCHUNK']._serialized_end=14263
  _globals['_FILEDOWNLOADINFO']._serialized_start=14265
  _globals['_FILEDOWNLOADINFO']._serialized_end=14339
  _globals['_FILEUPLOADCHUNK']._serialized_start=14341
  _globals['_FILEUPLOADCHUNK']._serialized_end=14444
  _globals['_FILEUPLOADINFO']._serialized_start=14446
  _globals['_FILEUPLOADINFO']._serialized_end=14488
  _globals['_IMAGEDOWNLOADCHUNK']._serialized_start=14490
  _globals['_IMAGEDOWNLOADCHUNK']._serialized_end=14595
  _globals['_IMAGEDOWNLOADINFO']._serialized_start=14597
  _globals['_IMAGEDOWNLOADINFO']._serialized_end=14672
  _globals['_IMAGEUPLOADCHUNK']._serialized_start=14674
  _globals['_IMAGEUPLOADCHUNK']._serialized_end=14778
  _globals['_IMAGEUPLOADINFO']._serialized_start=14780
  _globals['_IMAGEUPLOADINFO']._serialized_end=14823
  _globals['_VISUALISATIONDESTROYREQUEST']._serialized_start=14825
  _globals['_VISUALISATIONDESTROYREQUEST']._serialized_end=14897
  _globals['_VISUALISATIONLISTREQUEST']._serialized_start=14899
  _globals['_VISUALISATIONLISTREQUEST']._serialized_end=14925
  _globals['_VISUALISATIONLISTRESPONSE']._serialized_start=14927
  _globals['_VISUALISATIONLISTRESPONSE']._serialized_end=15033
  _globals['_VISUALISATIONPARTIALUPDATEREQUEST']._serialized_start=15036
  _globals['_VISUALISATIONPARTIALUPDATEREQUEST']._serialized_end=16249
  _globals['_VISUALISATIONREQUEST']._serialized_start=16252
  _globals['_VISUALISATIONREQUEST']._serialized_end=17399
  _globals['_VISUALISATIONRESPONSE']._serialized_start=17402
  _globals['_VISUALISATIONRESPONSE']._serialized_end=18550
  _globals['_VISUALISATIONRETRIEVEBYNAMENSREQUEST']._serialized_start=18552
  _globals['_VISUALISATIONRETRIEVEBYNAMENSREQUEST']._serialized_end=18647
  _globals['_VISUALISATIONRETRIEVEREQUEST']._serialized_start=18649
  _globals['_VISUALISATIONRETRIEVEREQUEST']._serialized_end=18722
  _globals['_DATACONTROLLER']._serialized_start=18725
  _globals['_DATACONTROLLER']._serialized_end=20061
  _globals['_DATASUBSETCONTROLLER']._serialized_start=20064
  _globals['_DATASUBSETCONTROLLER']._serialized_end=20890
  _globals['_EVALUATIONCONTROLLER']._serialized_start=20893
  _globals['_EVALUATIONCONTROLLER']._serialized_end=22326
  _globals['_EXTRADATACONTROLLER']._serialized_start=22329
  _globals['_EXTRADATACONTROLLER']._serialized_end=23140
  _globals['_VISUALISATIONCONTROLLER']._serialized_start=23143
  _globals['_VISUALISATIONCONTROLLER']._serialized_end=24499
# @@protoc_insertion_point(module_scope)
